@@ -45,9 +45,6 @@
 /* SSSD domain name that is used for the auto-configured files domain */
 #define IMPLICIT_FILES_DOMAIN_NAME "implicit_files"
 
-
-static int confdb_get_enabled_domain_list(struct confdb_ctx *cdb,
-                                          TALLOC_CTX *ctx, char ***_result);
 static int confdb_get_domain_enabled(struct confdb_ctx *cdb,
                                      const char *domain, bool *_enabled);
 
@@ -242,7 +239,7 @@ int confdb_get_param(struct confdb_ctx *cdb,
     TALLOC_CTX *tmp_ctx;
     struct ldb_result *res;
     struct ldb_dn *dn;
-    char *secdn;
+    char *secdn = NULL;
     const char *attrs[] = { attribute, NULL };
     char **vals;
     struct ldb_message_element *el;
@@ -913,52 +910,11 @@ static char *confdb_get_domain_hostname(TALLOC_CTX *mem_ctx,
     return talloc_strdup(mem_ctx, sys);
 }
 
-static int confdb_get_domain_internal(struct confdb_ctx *cdb,
-                                      TALLOC_CTX *mem_ctx,
-                                      const char *name,
-                                      struct sss_domain_info **_domain)
+static errno_t confdb_init_domain(struct sss_domain_info *domain,
+                                  struct ldb_result *res)
 {
-    struct sss_domain_info *domain;
-    struct ldb_result *res;
-    TALLOC_CTX *tmp_ctx;
-    const char *tmp, *tmp_pam_target, *tmp_auth;
-    int ret, val;
-    uint32_t entry_cache_timeout;
-    char *default_domain;
-    bool fqnames_default = false;
-    int memcache_timeout;
-
-    tmp_ctx = talloc_new(mem_ctx);
-    if (!tmp_ctx) return ENOMEM;
-
-    ret = confdb_get_domain_section(tmp_ctx, cdb, CONFDB_DOMAIN_BASEDN,
-                                    name, &res);
-    if (ret == ENOENT) {
-        DEBUG(SSSDBG_FATAL_FAILURE, "Unknown domain [%s]\n", name);
-        goto done;
-    } else if (ret != EOK) {
-        DEBUG(SSSDBG_FATAL_FAILURE,
-              "Error %d: %s while retrieving %s\n",
-              ret, sss_strerror(ret), name);
-        goto done;
-    }
-
-    ret = confdb_get_int(cdb,
-                         CONFDB_NSS_CONF_ENTRY,
-                         CONFDB_MEMCACHE_TIMEOUT,
-                         300, &memcache_timeout);
-    if (ret != EOK) {
-        DEBUG(SSSDBG_FATAL_FAILURE,
-              "Unable to get memory cache entry timeout [%s].\n",
-              CONFDB_MEMCACHE_TIMEOUT);
-        goto done;
-    }
-
-    domain = talloc_zero(mem_ctx, struct sss_domain_info);
-    if (!domain) {
-        ret = ENOMEM;
-        goto done;
-    }
+    errno_t ret;
+    const char *tmp;
 
     tmp = ldb_msg_find_attr_as_string(res->msgs[0], "cn", NULL);
     if (!tmp) {
@@ -1002,7 +958,111 @@ static int confdb_get_domain_internal(struct confdb_ctx *cdb,
     domain->timeout = ldb_msg_find_attr_as_int(res->msgs[0],
                                                CONFDB_DOMAIN_TIMEOUT, 0);
 
-    /* Determine if this domain can be enumerated */
+    ret = get_entry_as_bool(res->msgs[0], &domain->ignore_group_members,
+                            CONFDB_DOMAIN_IGNORE_GROUP_MEMBERS, 0);
+    if (ret != EOK) {
+        DEBUG(SSSDBG_FATAL_FAILURE,
+              "Invalid value for %s\n",
+               CONFDB_DOMAIN_IGNORE_GROUP_MEMBERS);
+        goto done;
+    }
+
+    ret = get_entry_as_uint32(res->msgs[0], &domain->id_min,
+                              CONFDB_DOMAIN_MINID,
+                              confdb_get_min_id(domain));
+    if (ret != EOK) {
+        DEBUG(SSSDBG_FATAL_FAILURE, "Invalid value for minId\n");
+        ret = EINVAL;
+        goto done;
+    }
+
+    ret = get_entry_as_uint32(res->msgs[0], &domain->id_max,
+                              CONFDB_DOMAIN_MAXID, 0);
+    if (ret != EOK) {
+        DEBUG(SSSDBG_FATAL_FAILURE, "Invalid value for maxId\n");
+        ret = EINVAL;
+        goto done;
+    }
+
+    if (domain->id_max && (domain->id_max < domain->id_min)) {
+        DEBUG(SSSDBG_FATAL_FAILURE, "Invalid domain range\n");
+        ret = EINVAL;
+        goto done;
+    }
+
+    /* Do we allow to cache credentials */
+    ret = get_entry_as_bool(res->msgs[0], &domain->cache_credentials,
+                            CONFDB_DOMAIN_CACHE_CREDS, 0);
+    if (ret != EOK) {
+        DEBUG(SSSDBG_FATAL_FAILURE,
+              "Invalid value for %s\n", CONFDB_DOMAIN_CACHE_CREDS);
+        goto done;
+    }
+
+    ret = get_entry_as_uint32(res->msgs[0],
+                              &domain->cache_credentials_min_ff_length,
+                              CONFDB_DOMAIN_CACHE_CREDS_MIN_FF_LENGTH,
+                              CONFDB_DEFAULT_CACHE_CREDS_MIN_FF_LENGTH);
+    if (ret != EOK) {
+        DEBUG(SSSDBG_FATAL_FAILURE,
+              "Invalid value for %s\n",
+              CONFDB_DOMAIN_CACHE_CREDS_MIN_FF_LENGTH);
+        goto done;
+    }
+
+    ret = get_entry_as_uint32(res->msgs[0], &domain->override_gid,
+                              CONFDB_DOMAIN_OVERRIDE_GID, 0);
+    if (ret != EOK) {
+        DEBUG(SSSDBG_FATAL_FAILURE,
+              "Invalid value for [%s]\n", CONFDB_DOMAIN_OVERRIDE_GID);
+        goto done;
+    }
+
+    domain->hostname = confdb_get_domain_hostname(domain, res, domain->provider);
+    if (domain->hostname == NULL) {
+        DEBUG(SSSDBG_CRIT_FAILURE, "Unable to get domain hostname\n");
+        goto done;
+    }
+
+    domain->krb5_keytab = NULL;
+    tmp = ldb_msg_find_attr_as_string(res->msgs[0], "krb5_keytab", NULL);
+    if (tmp != NULL) {
+        domain->krb5_keytab = talloc_strdup(domain, tmp);
+        if (domain->krb5_keytab == NULL) {
+            DEBUG(SSSDBG_CRIT_FAILURE, "Unable to get domain keytab!\n");
+            goto done;
+        }
+    }
+
+    domain->has_views = false;
+    domain->view_name = NULL;
+
+    domain->state = DOM_ACTIVE;
+
+    domain->fallback_to_nss = false;
+    if (is_files_provider(domain)) {
+        ret = get_entry_as_bool(res->msgs[0], &domain->fallback_to_nss,
+                                CONFDB_DOMAIN_FALLBACK_TO_NSS, true);
+        if(ret != EOK) {
+            DEBUG(SSSDBG_FATAL_FAILURE,
+                  "Invalid value for %s\n", CONFDB_DOMAIN_FALLBACK_TO_NSS);
+            goto done;
+        }
+    }
+
+    domain->not_found_counter = 0;
+    ret = EOK;
+
+done:
+    return ret;
+}
+
+static errno_t confdb_init_domain_provider_and_enum(struct sss_domain_info *domain,
+                                                    struct ldb_result *res)
+{
+    int val;
+    errno_t ret;
+    const char *tmp, *tmp_pam_target, *tmp_auth;
 
     /* TEMP: test if the old bitfield conf value is used and warn it has been
      * superseded. */
@@ -1042,8 +1102,8 @@ static int confdb_get_domain_internal(struct confdb_ctx *cdb,
                                           NULL);
 
         tmp_auth = ldb_msg_find_attr_as_string(res->msgs[0],
-                                                CONFDB_DOMAIN_AUTH_PROVIDER,
-                                                NULL);
+                                               CONFDB_DOMAIN_AUTH_PROVIDER,
+                                               NULL);
 
         tmp_pam_target = ldb_msg_find_attr_as_string(res->msgs[0],
                                                      CONFDB_PROXY_PAM_TARGET,
@@ -1065,7 +1125,22 @@ static int confdb_get_domain_internal(struct confdb_ctx *cdb,
               "sssd.conf man page for more detailed information\n");
     }
 
-    ret = confdb_get_string(cdb, tmp_ctx, CONFDB_MONITOR_CONF_ENTRY,
+    ret = EOK;
+
+done:
+    return ret;
+}
+
+static errno_t confdb_init_domain_fqn(struct confdb_ctx *cdb,
+                                      TALLOC_CTX *mem_ctx,
+                                      struct sss_domain_info *domain,
+                                      struct ldb_result *res)
+{
+    errno_t ret;
+    char *default_domain;
+    bool fqnames_default = false;
+
+    ret = confdb_get_string(cdb, mem_ctx, CONFDB_MONITOR_CONF_ENTRY,
                             CONFDB_MONITOR_DEFAULT_DOMAIN, NULL,
                             &default_domain);
     if (ret != EOK) {
@@ -1103,55 +1178,28 @@ static int confdb_get_domain_internal(struct confdb_ctx *cdb,
         goto done;
     }
 
-    ret = get_entry_as_bool(res->msgs[0], &domain->ignore_group_members,
-                            CONFDB_DOMAIN_IGNORE_GROUP_MEMBERS, 0);
-    if(ret != EOK) {
-        DEBUG(SSSDBG_FATAL_FAILURE,
-              "Invalid value for %s\n",
-               CONFDB_DOMAIN_IGNORE_GROUP_MEMBERS);
-        goto done;
-    }
+    ret = EOK;
 
-    ret = get_entry_as_uint32(res->msgs[0], &domain->id_min,
-                              CONFDB_DOMAIN_MINID,
-                              confdb_get_min_id(domain));
-    if (ret != EOK) {
-        DEBUG(SSSDBG_FATAL_FAILURE, "Invalid value for minId\n");
-        ret = EINVAL;
-        goto done;
-    }
+done:
+    return ret;
+}
 
-    ret = get_entry_as_uint32(res->msgs[0], &domain->id_max,
-                              CONFDB_DOMAIN_MAXID, 0);
-    if (ret != EOK) {
-        DEBUG(SSSDBG_FATAL_FAILURE, "Invalid value for maxId\n");
-        ret = EINVAL;
-        goto done;
-    }
+static errno_t confdb_init_domain_timeouts(struct confdb_ctx *cdb,
+                                           struct sss_domain_info *domain,
+                                           struct ldb_result *res)
+{
+    errno_t ret;
+    uint32_t entry_cache_timeout;
+    int memcache_timeout;
 
-    if (domain->id_max && (domain->id_max < domain->id_min)) {
-        DEBUG(SSSDBG_FATAL_FAILURE, "Invalid domain range\n");
-        ret = EINVAL;
-        goto done;
-    }
-
-    /* Do we allow to cache credentials */
-    ret = get_entry_as_bool(res->msgs[0], &domain->cache_credentials,
-                            CONFDB_DOMAIN_CACHE_CREDS, 0);
-    if(ret != EOK) {
-        DEBUG(SSSDBG_FATAL_FAILURE,
-              "Invalid value for %s\n", CONFDB_DOMAIN_CACHE_CREDS);
-        goto done;
-    }
-
-    ret = get_entry_as_uint32(res->msgs[0],
-                              &domain->cache_credentials_min_ff_length,
-                              CONFDB_DOMAIN_CACHE_CREDS_MIN_FF_LENGTH,
-                              CONFDB_DEFAULT_CACHE_CREDS_MIN_FF_LENGTH);
+    ret = confdb_get_int(cdb,
+                         CONFDB_NSS_CONF_ENTRY,
+                         CONFDB_MEMCACHE_TIMEOUT,
+                         300, &memcache_timeout);
     if (ret != EOK) {
         DEBUG(SSSDBG_FATAL_FAILURE,
-              "Invalid value for %s\n",
-              CONFDB_DOMAIN_CACHE_CREDS_MIN_FF_LENGTH);
+              "Unable to get memory cache entry timeout [%s].\n",
+              CONFDB_MEMCACHE_TIMEOUT);
         goto done;
     }
 
@@ -1161,7 +1209,7 @@ static int confdb_get_domain_internal(struct confdb_ctx *cdb,
     if (ret != EOK) {
         DEBUG(SSSDBG_FATAL_FAILURE,
               "Invalid value for [%s]\n",
-                CONFDB_DOMAIN_ENTRY_CACHE_TIMEOUT);
+              CONFDB_DOMAIN_ENTRY_CACHE_TIMEOUT);
         goto done;
     }
 
@@ -1172,7 +1220,7 @@ static int confdb_get_domain_internal(struct confdb_ctx *cdb,
     if (ret != EOK) {
         DEBUG(SSSDBG_FATAL_FAILURE,
               "Invalid value for [%s]\n",
-               CONFDB_DOMAIN_USER_CACHE_TIMEOUT);
+              CONFDB_DOMAIN_USER_CACHE_TIMEOUT);
         goto done;
     }
 
@@ -1190,7 +1238,7 @@ static int confdb_get_domain_internal(struct confdb_ctx *cdb,
     if (ret != EOK) {
         DEBUG(SSSDBG_FATAL_FAILURE,
               "Invalid value for [%s]\n",
-               CONFDB_DOMAIN_GROUP_CACHE_TIMEOUT);
+              CONFDB_DOMAIN_GROUP_CACHE_TIMEOUT);
         goto done;
     }
 
@@ -1208,7 +1256,7 @@ static int confdb_get_domain_internal(struct confdb_ctx *cdb,
     if (ret != EOK) {
         DEBUG(SSSDBG_FATAL_FAILURE,
               "Invalid value for [%s]\n",
-               CONFDB_DOMAIN_NETGROUP_CACHE_TIMEOUT);
+              CONFDB_DOMAIN_NETGROUP_CACHE_TIMEOUT);
         goto done;
     }
 
@@ -1219,7 +1267,7 @@ static int confdb_get_domain_internal(struct confdb_ctx *cdb,
     if (ret != EOK) {
         DEBUG(SSSDBG_FATAL_FAILURE,
               "Invalid value for [%s]\n",
-               CONFDB_DOMAIN_SERVICE_CACHE_TIMEOUT);
+              CONFDB_DOMAIN_SERVICE_CACHE_TIMEOUT);
         goto done;
     }
 
@@ -1230,7 +1278,7 @@ static int confdb_get_domain_internal(struct confdb_ctx *cdb,
     if (ret != EOK) {
         DEBUG(SSSDBG_FATAL_FAILURE,
               "Invalid value for [%s]\n",
-               CONFDB_DOMAIN_AUTOFS_CACHE_TIMEOUT);
+              CONFDB_DOMAIN_AUTOFS_CACHE_TIMEOUT);
         goto done;
     }
 
@@ -1241,7 +1289,7 @@ static int confdb_get_domain_internal(struct confdb_ctx *cdb,
     if (ret != EOK) {
         DEBUG(SSSDBG_FATAL_FAILURE,
               "Invalid value for [%s]\n",
-               CONFDB_DOMAIN_SUDO_CACHE_TIMEOUT);
+              CONFDB_DOMAIN_SUDO_CACHE_TIMEOUT);
         goto done;
     }
 
@@ -1274,7 +1322,7 @@ static int confdb_get_domain_internal(struct confdb_ctx *cdb,
     if (ret != EOK) {
         DEBUG(SSSDBG_FATAL_FAILURE,
               "Invalid value for [%s]\n",
-               CONFDB_DOMAIN_RESOLVER_CACHE_TIMEOUT);
+              CONFDB_DOMAIN_RESOLVER_CACHE_TIMEOUT);
         goto done;
     }
 
@@ -1285,60 +1333,66 @@ static int confdb_get_domain_internal(struct confdb_ctx *cdb,
     if (ret != EOK) {
         DEBUG(SSSDBG_FATAL_FAILURE,
               "Invalid value for [%s]\n",
-               CONFDB_DOMAIN_REFRESH_EXPIRED_INTERVAL);
+              CONFDB_DOMAIN_REFRESH_EXPIRED_INTERVAL);
+        goto done;
+    }
+
+    /* Set refresh_expired_interval_offset, if specified */
+    ret = get_entry_as_uint32(res->msgs[0],
+                              &domain->refresh_expired_interval_offset,
+                              CONFDB_DOMAIN_REFRESH_EXPIRED_INTERVAL_OFFSET,
+                              0);
+    if (ret != EOK) {
+        DEBUG(SSSDBG_FATAL_FAILURE,
+              "Invalid value for [%s]\n",
+              CONFDB_DOMAIN_REFRESH_EXPIRED_INTERVAL_OFFSET);
         goto done;
     }
 
     /* detect and fix misconfiguration */
-    if (domain->refresh_expired_interval > entry_cache_timeout) {
+    if (domain->refresh_expired_interval + domain->refresh_expired_interval_offset > entry_cache_timeout) {
         DEBUG(SSSDBG_CONF_SETTINGS,
-              "refresh_expired_interval (%d) cannot be greater than "
+              "refresh_expired_interval (%d) + "
+              "refresh_expired_interval_offset (%d) cannot be greater than "
               "entry_cache_timeout (%u)\n",
-              domain->refresh_expired_interval, entry_cache_timeout);
+              domain->refresh_expired_interval,
+              domain->refresh_expired_interval_offset, entry_cache_timeout);
 
-        domain->refresh_expired_interval = 0.75 * entry_cache_timeout;
+        domain->refresh_expired_interval = 0.70 * entry_cache_timeout;
+        domain->refresh_expired_interval_offset =
+                0.10 * domain->refresh_expired_interval;
 
         DEBUG(SSSDBG_CONF_SETTINGS,
               "refresh_expired_interval is being set to recommended value "
-              "entry_cache_timeout * 0.75 (%u).\n",
+              "entry_cache_timeout * 0.70 (%u).\n",
               domain->refresh_expired_interval);
-    }
-
-    /* Set the PAM warning time, if specified. If not specified, pass on
-     * the "not set" value of "-1" which means "use provider default". The
-     * value 0 means "always display the warning if server sends one" */
-    domain->pwd_expiration_warning = -1;
-
-    val = ldb_msg_find_attr_as_int(res->msgs[0],
-                                   CONFDB_DOMAIN_PWD_EXPIRATION_WARNING,
-                                   -1);
-    if (val == -1) {
-        ret = confdb_get_int(cdb, CONFDB_PAM_CONF_ENTRY,
-                             CONFDB_PAM_PWD_EXPIRATION_WARNING,
-                             -1, &val);
-        if (ret != EOK) {
-            DEBUG(SSSDBG_CRIT_FAILURE,
-                  "Failed to read PAM expiration warning, not fatal.\n");
-            val = -1;
-        }
-    }
-
-    DEBUG(SSSDBG_TRACE_LIBS, "pwd_expiration_warning is %d\n", val);
-    if (val >= 0) {
         DEBUG(SSSDBG_CONF_SETTINGS,
-              "Setting domain password expiration warning to %d days\n", val);
-        /* The value is in days, transform it to seconds */
-        domain->pwd_expiration_warning = val * 24 * 3600;
+              "refresh_expired_interval_offset is being set to recommended value "
+              "refresh_expired_interval * 0.10 (%u).\n",
+              domain->refresh_expired_interval_offset);
     }
 
-    ret = get_entry_as_uint32(res->msgs[0], &domain->override_gid,
-                              CONFDB_DOMAIN_OVERRIDE_GID, 0);
+    ret = init_cached_auth_timeout(cdb, res->msgs[0],
+                                   &domain->cached_auth_timeout);
     if (ret != EOK) {
-        DEBUG(SSSDBG_FATAL_FAILURE,
-              "Invalid value for [%s]\n", CONFDB_DOMAIN_OVERRIDE_GID);
+        DEBUG(SSSDBG_CRIT_FAILURE,
+              "init_cached_auth_timeout failed: %s:[%d].\n",
+              sss_strerror(ret), ret);
         goto done;
     }
 
+    ret = EOK;
+
+done:
+    return ret;
+}
+
+static errno_t confdb_init_domain_user_info(struct sss_domain_info *domain,
+                                            struct ldb_result *res)
+{
+    errno_t ret;
+    const char *tmp;
+
     tmp = ldb_msg_find_attr_as_string(res->msgs[0],
                                       CONFDB_NSS_OVERRIDE_HOMEDIR, NULL);
     /* Here we skip the files provider as it should always return *only*
@@ -1391,8 +1445,7 @@ static int confdb_get_domain_internal(struct confdb_ctx *cdb,
         }
     }
 
-    tmp = ldb_msg_find_attr_as_string(res->msgs[0],
-                                      CONFDB_NSS_OVERRIDE_SHELL, NULL);
+    tmp = ldb_msg_find_attr_as_string(res->msgs[0], CONFDB_NSS_OVERRIDE_SHELL, NULL);
     /* Here we skip the files provider as it should always return *only*
      * what's in the files and nothing else. */
     if (tmp != NULL && !is_files_provider(domain)) {
@@ -1403,8 +1456,7 @@ static int confdb_get_domain_internal(struct confdb_ctx *cdb,
         }
     }
 
-    tmp = ldb_msg_find_attr_as_string(res->msgs[0],
-                                      CONFDB_NSS_DEFAULT_SHELL, NULL);
+    tmp = ldb_msg_find_attr_as_string(res->msgs[0], CONFDB_NSS_DEFAULT_SHELL, NULL);
     if (tmp != NULL) {
         domain->default_shell = talloc_strdup(domain, tmp);
         if (!domain->default_shell) {
@@ -1413,6 +1465,27 @@ static int confdb_get_domain_internal(struct confdb_ctx *cdb,
         }
     }
 
+    tmp = ldb_msg_find_attr_as_string(res->msgs[0], CONFDB_NSS_PWFIELD, NULL);
+    if (tmp != NULL) {
+        domain->pwfield = talloc_strdup(domain, tmp);
+        if (!domain->pwfield) {
+            ret = ENOMEM;
+            goto done;
+        }
+    }
+
+    ret = EOK;
+
+done:
+    return ret;
+}
+
+static errno_t confdb_init_domain_case(struct sss_domain_info *domain,
+                                       struct ldb_result *res)
+{
+    errno_t ret;
+    const char *tmp;
+
     tmp = ldb_msg_find_attr_as_string(res->msgs[0],
                                       CONFDB_DOMAIN_CASE_SENSITIVE, NULL);
     if (tmp != NULL) {
@@ -1442,15 +1515,17 @@ static int confdb_get_domain_internal(struct confdb_ctx *cdb,
         }
     }
 
-    tmp = ldb_msg_find_attr_as_string(res->msgs[0],
-                                      CONFDB_NSS_PWFIELD, NULL);
-    if (tmp != NULL) {
-        domain->pwfield = talloc_strdup(domain, tmp);
-        if (!domain->pwfield) {
-            ret = ENOMEM;
-            goto done;
-        }
-    }
+    ret = EOK;
+
+done:
+    return ret;
+}
+
+static errno_t confdb_init_domain_subdomains(struct sss_domain_info *domain,
+                                             struct ldb_result *res)
+{
+    errno_t ret;
+    const char *tmp;
 
     tmp = ldb_msg_find_attr_as_string(res->msgs[0],
                                       CONFDB_SUBDOMAIN_ENUMERATE,
@@ -1512,30 +1587,27 @@ static int confdb_get_domain_internal(struct confdb_ctx *cdb,
             CONFDB_DOMAIN_SUBDOMAIN_REFRESH_DEFAULT_VALUE;
     }
 
-    ret = init_cached_auth_timeout(cdb, res->msgs[0],
-                                   &domain->cached_auth_timeout);
+    ret = get_entry_as_uint32(res->msgs[0],
+                              &domain->subdomain_refresh_interval_offset,
+                              CONFDB_DOMAIN_SUBDOMAIN_REFRESH_OFFSET,
+                              CONFDB_DOMAIN_SUBDOMAIN_REFRESH_OFFSET_DEFAULT_VALUE);
     if (ret != EOK) {
-        DEBUG(SSSDBG_CRIT_FAILURE,
-              "init_cached_auth_timeout failed: %s:[%d].\n",
-              sss_strerror(ret), ret);
+        DEBUG(SSSDBG_FATAL_FAILURE,
+              "Invalid value for [%s]\n", CONFDB_DOMAIN_SUBDOMAIN_REFRESH_OFFSET);
         goto done;
     }
 
-    domain->hostname = confdb_get_domain_hostname(domain, res, domain->provider);
-    if (domain->hostname == NULL) {
-        DEBUG(SSSDBG_CRIT_FAILURE, "Unable to get domain hostname\n");
-        goto done;
-    }
+    ret = EOK;
 
-    domain->krb5_keytab = NULL;
-    tmp = ldb_msg_find_attr_as_string(res->msgs[0], "krb5_keytab", NULL);
-    if (tmp != NULL) {
-        domain->krb5_keytab = talloc_strdup(domain, tmp);
-        if (domain->krb5_keytab == NULL) {
-            DEBUG(SSSDBG_CRIT_FAILURE, "Unable to get domain keytab!\n");
-            goto done;
-        }
-    }
+done:
+    return ret;
+}
+
+static errno_t confdb_init_domain_gssapi(struct sss_domain_info *domain,
+                                         struct ldb_result *res)
+{
+    errno_t ret;
+    const char *tmp;
 
     tmp = ldb_msg_find_attr_as_string(res->msgs[0], CONFDB_PAM_GSSAPI_SERVICES,
                                       NULL);
@@ -1572,23 +1644,132 @@ static int confdb_get_domain_internal(struct confdb_ctx *cdb,
         }
     }
 
-    domain->has_views = false;
-    domain->view_name = NULL;
+    ret = EOK;
 
-    domain->state = DOM_ACTIVE;
+done:
+    return ret;
+}
 
-    domain->fallback_to_nss = false;
-    if (is_files_provider(domain)) {
-        ret = get_entry_as_bool(res->msgs[0], &domain->fallback_to_nss,
-                                CONFDB_DOMAIN_FALLBACK_TO_NSS, true);
-        if(ret != EOK) {
-            DEBUG(SSSDBG_FATAL_FAILURE,
-                  "Invalid value for %s\n", CONFDB_DOMAIN_FALLBACK_TO_NSS);
-            goto done;
+static errno_t confdb_init_domain_pwd_expire(struct confdb_ctx *cdb,
+                                             struct sss_domain_info *domain,
+                                             struct ldb_result *res)
+{
+    int val;
+    errno_t ret;
+
+    /* Set the PAM warning time, if specified. If not specified, pass on
+     * the "not set" value of "-1" which means "use provider default". The
+     * value 0 means "always display the warning if server sends one" */
+    domain->pwd_expiration_warning = -1;
+
+    val = ldb_msg_find_attr_as_int(res->msgs[0],
+                                   CONFDB_DOMAIN_PWD_EXPIRATION_WARNING,
+                                   -1);
+    if (val == -1) {
+        ret = confdb_get_int(cdb, CONFDB_PAM_CONF_ENTRY,
+                             CONFDB_PAM_PWD_EXPIRATION_WARNING,
+                             -1, &val);
+        if (ret != EOK) {
+            DEBUG(SSSDBG_CRIT_FAILURE,
+                  "Failed to read PAM expiration warning, not fatal.\n");
+            val = -1;
         }
     }
 
-    domain->not_found_counter = 0;
+    DEBUG(SSSDBG_TRACE_LIBS, "pwd_expiration_warning is %d\n", val);
+    if (val >= 0) {
+        DEBUG(SSSDBG_CONF_SETTINGS,
+              "Setting domain password expiration warning to %d days\n", val);
+        /* The value is in days, transform it to seconds */
+        domain->pwd_expiration_warning = val * 24 * 3600;
+    }
+
+    return EOK;
+}
+
+static int confdb_get_domain_internal(struct confdb_ctx *cdb,
+                                      TALLOC_CTX *mem_ctx,
+                                      const char *name,
+                                      struct sss_domain_info **_domain)
+{
+    struct sss_domain_info *domain;
+    struct ldb_result *res;
+    TALLOC_CTX *tmp_ctx;
+    errno_t ret;
+
+    tmp_ctx = talloc_new(mem_ctx);
+    if (!tmp_ctx) return ENOMEM;
+
+    ret = confdb_get_domain_section(tmp_ctx, cdb, CONFDB_DOMAIN_BASEDN,
+                                    name, &res);
+    if (ret == ENOENT) {
+        DEBUG(SSSDBG_FATAL_FAILURE, "Unknown domain [%s]\n", name);
+        goto done;
+    } else if (ret != EOK) {
+        DEBUG(SSSDBG_FATAL_FAILURE,
+              "Error %d: %s while retrieving %s\n",
+              ret, sss_strerror(ret), name);
+        goto done;
+    }
+
+    domain = talloc_zero(mem_ctx, struct sss_domain_info);
+    if (!domain) {
+        ret = ENOMEM;
+        goto done;
+    }
+
+    ret = confdb_init_domain(domain, res);
+    if (ret != EOK) {
+        goto done;
+    }
+
+    /* Determine if this domain can be enumerated */
+    ret = confdb_init_domain_provider_and_enum(domain, res);
+    if (ret != EOK) {
+        goto done;
+    }
+
+    ret = confdb_init_domain_fqn(cdb, mem_ctx, domain, res);
+    if (ret != EOK) {
+        goto done;
+    }
+
+    /* Get all the timeouts */
+    ret = confdb_init_domain_timeouts(cdb, domain, res);
+    if (ret != EOK) {
+        goto done;
+    }
+
+    /* Get password expiration information */
+    ret = confdb_init_domain_pwd_expire(cdb, domain, res);
+    if (ret != EOK) {
+        goto done;
+    }
+
+    /* Get the behavior about the homedir */
+    ret = confdb_init_domain_user_info(domain, res);
+    if (ret != EOK) {
+        goto done;
+    }
+
+    /* Get the case sensitivity */
+    ret = confdb_init_domain_case(domain, res);
+    if (ret != EOK) {
+        goto done;
+    }
+
+    /* Get the subdomains information */
+    ret = confdb_init_domain_subdomains(domain, res);
+    if (ret != EOK) {
+        goto done;
+    }
+
+    /* Get the GSSAPI information */
+    ret = confdb_init_domain_gssapi(domain, res);
+    if (ret != EOK) {
+        goto done;
+    }
+
 
     *_domain = domain;
     ret = EOK;
@@ -1615,10 +1796,10 @@ int confdb_get_domains(struct confdb_ctx *cdb,
 
     ret = confdb_get_enabled_domain_list(cdb, tmp_ctx, &domlist);
     if (ret == ENOENT) {
-        DEBUG(SSSDBG_MINOR_FAILURE, "No domains configured, fatal error!\n");
+        DEBUG(SSSDBG_CRIT_FAILURE, "No domains configured, fatal error!\n");
+        ret = ERR_NO_DOMAIN_ENABLED;
         goto done;
-    }
-    if (ret != EOK ) {
+    } else if (ret != EOK) {
         DEBUG(SSSDBG_FATAL_FAILURE, "Fatal error retrieving domains list!\n");
         goto done;
     }
@@ -1638,7 +1819,7 @@ int confdb_get_domains(struct confdb_ctx *cdb,
         }
 
         domain = NULL;
-        ret = confdb_get_domain_internal(cdb, cdb, domlist[i], &domain);
+       ret = confdb_get_domain_internal(cdb, cdb, domlist[i], &domain);
         if (ret) {
             DEBUG(SSSDBG_FATAL_FAILURE,
                   RETRIEVE_DOMAIN_ERROR_MSG,
@@ -2284,14 +2465,12 @@ int confdb_expand_app_domains(struct confdb_ctx *cdb)
         /* Not fatal */
     }
 
-    ret = confdb_get_string_as_list(cdb, tmp_ctx,
-                                    CONFDB_MONITOR_CONF_ENTRY,
-                                    CONFDB_MONITOR_ACTIVE_DOMAINS,
-                                    &domlist);
+    ret = confdb_get_enabled_domain_list(cdb, tmp_ctx, &domlist);
     if (ret == ENOENT) {
         DEBUG(SSSDBG_FATAL_FAILURE, "No domains configured, fatal error!\n");
+        ret = ERR_NO_DOMAIN_ENABLED;
         goto done;
-    } else if (ret != EOK ) {
+    } else if (ret != EOK) {
         DEBUG(SSSDBG_FATAL_FAILURE, "Fatal error retrieving domains list!\n");
         goto done;
     }
@@ -2492,16 +2671,8 @@ done:
     return ret;
 }
 
-/**
- * Retrieve the list of enabled domains considering the explicit list
- * and the 'enabled' attribute.
- * @param cdb The database configuration context.
- * @param ctx The memory context.
- * @param result Output variable where the list of domains will be stored.
- * @return 0 if the list was retrieved properly, another value on error.
- */
-static int confdb_get_enabled_domain_list(struct confdb_ctx *cdb,
-                                          TALLOC_CTX *ctx, char ***_result)
+int confdb_get_enabled_domain_list(struct confdb_ctx *cdb,
+                                   TALLOC_CTX *ctx, char ***_result)
 {
     int ret;
     char **domlist = NULL;
@@ -2515,7 +2686,7 @@ static int confdb_get_enabled_domain_list(struct confdb_ctx *cdb,
                                     CONFDB_MONITOR_CONF_ENTRY,
                                     CONFDB_MONITOR_ACTIVE_DOMAINS,
                                     &domlist);
-    if (ret != EOK) {
+    if (ret != EOK && ret != ENOENT) {
         DEBUG(SSSDBG_OP_FAILURE,
               "Failed to get [%s] from [%s], error [%d] (%s)\n",
               CONFDB_MONITOR_ACTIVE_DOMAINS, "sssd",
@@ -2570,6 +2741,11 @@ static int confdb_get_enabled_domain_list(struct confdb_ctx *cdb,
         }
     }
 
+    if (domlist == NULL || domlist[0] == NULL) {
+        ret = ENOENT;
+        goto done;
+    }
+
     ret = EOK;
     talloc_steal(ctx, domlist);
     *_result = domlist;
