@@ -31,6 +31,9 @@
 #define CACHE_TIMESTAMPS_FILE "timestamps_%s.ldb"
 #define LOCAL_SYSDB_FILE "sssd.ldb"
 
+#define SYSDB_INDEXES "@INDEXLIST"
+#define SYSDB_IDXATTR "@IDXATTR"
+
 #define SYSDB_BASE "cn=sysdb"
 #define SYSDB_DOM_BASE "cn=%s,cn=sysdb"
 #define SYSDB_USERS_CONTAINER "cn=users"
@@ -373,6 +376,12 @@ enum sysdb_member_type {
     SYSDB_MEMBER_IP_NETWORK,
 };
 
+enum sysdb_index_actions {
+    SYSDB_IDX_CREATE,
+    SYSDB_IDX_DELETE,
+    SYSDB_IDX_LIST
+};
+
 /* These attributes are stored in the timestamp cache */
 extern const char *sysdb_ts_cache_attrs[];
 
@@ -435,27 +444,11 @@ int sysdb_attrs_users_from_str_list(struct sysdb_attrs *attrs,
                                     const char *attr_name,
                                     const char *domain,
                                     const char *const *list);
-errno_t sysdb_attrs_primary_name(struct sysdb_ctx *sysdb,
-                                 struct sysdb_attrs *attrs,
-                                 const char *ldap_attr,
-                                 const char **_primary);
 errno_t sysdb_attrs_get_aliases(TALLOC_CTX *mem_ctx,
                                 struct sysdb_attrs *attrs,
                                 const char *primary,
                                 bool lowercase,
                                 const char ***_aliases);
-errno_t sysdb_attrs_primary_name_list(struct sss_domain_info *domain,
-                                      TALLOC_CTX *mem_ctx,
-                                      struct sysdb_attrs **attr_list,
-                                      size_t attr_count,
-                                      const char *ldap_attr,
-                                      char ***name_list);
-errno_t sysdb_attrs_primary_fqdn_list(struct sss_domain_info *domain,
-                                      TALLOC_CTX *mem_ctx,
-                                      struct sysdb_attrs **attr_list,
-                                      size_t attr_count,
-                                      const char *ldap_attr,
-                                      char ***name_list);
 errno_t sysdb_get_real_name(TALLOC_CTX *mem_ctx,
                             struct sss_domain_info *domain,
                             const char *name_or_upn,
@@ -825,7 +818,8 @@ int sysdb_enumpwent(TALLOC_CTX *mem_ctx,
 
 int sysdb_enumpwent_filter(TALLOC_CTX *mem_ctx,
                            struct sss_domain_info *domain,
-                           const char *name_filter,
+                           const char *attr,
+                           const char *attr_filter,
                            const char *addtl_filter,
                            struct ldb_result **res);
 
@@ -835,7 +829,8 @@ int sysdb_enumpwent_with_views(TALLOC_CTX *mem_ctx,
 
 int sysdb_enumpwent_filter_with_views(TALLOC_CTX *mem_ctx,
                                       struct sss_domain_info *domain,
-                                      const char *name_filter,
+                                      const char *attr,
+                                      const char *attr_filter,
                                       const char *addtl_filter,
                                       struct ldb_result **res);
 
