@@ -25,6 +25,12 @@
 #include <time.h>
 #include <ctype.h>
 
+
+static inline bool is_sysdb_name(const char *attr)
+{
+    return (attr != NULL && strcmp(attr, SYSDB_NAME) == 0);
+}
+
 /* helpers */
 static errno_t merge_ts_attr(struct ldb_message *ts_msg,
                              struct ldb_message *sysdb_msg,
@@ -525,9 +531,37 @@ done:
     return ret;
 }
 
+static char *filter_attribute(TALLOC_CTX *mem_ctx,
+                              const char *attr,
+                              const char *attr_filter,
+                              const char *domain,
+                              char *filter)
+{
+    char *new_filter = NULL;
+    const char *value;
+
+    if (filter == NULL) {
+        return NULL;
+    }
+
+    if (domain != NULL && is_sysdb_name(attr)) {
+        value = sss_create_internal_fqname(mem_ctx, attr_filter, domain);
+    } else {
+        value = attr_filter;
+    }
+
+    if (value != NULL) {
+        new_filter = talloc_asprintf_append(filter, "(%s=%s)", attr, value);
+    }
+
+    return new_filter;
+}
+
 static char *enum_filter(TALLOC_CTX *mem_ctx,
                          const char *base_filter,
-                         const char *name_filter,
+                         const char *attr,
+                         const char *attr_filter,
+                         const char *domain,
                          const char *addtl_filter)
 {
     char *filter;
@@ -538,14 +572,13 @@ static char *enum_filter(TALLOC_CTX *mem_ctx,
         return NULL;
     }
 
-    if (name_filter == NULL && addtl_filter == NULL) {
+    if ((attr == NULL || attr_filter == NULL) && addtl_filter == NULL) {
         filter = talloc_strdup(tmp_ctx, base_filter);
     } else {
         filter = talloc_asprintf(tmp_ctx, "(&%s", base_filter);
 
-        if (filter != NULL && name_filter != NULL) {
-            filter = talloc_asprintf_append(filter, "(%s=%s)",
-                                            SYSDB_NAME, name_filter);
+        if (filter != NULL && attr != NULL && attr_filter != NULL) {
+            filter = filter_attribute(tmp_ctx, attr, attr_filter, domain, filter);
         }
 
         if (filter != NULL && addtl_filter != NULL) {
@@ -776,10 +809,12 @@ done:
 static errno_t sysdb_enum_dn_filter(TALLOC_CTX *mem_ctx,
                                     struct ldb_result *ts_res,
                                     const char *name_filter,
+                                    const char *domain,
                                     char **_dn_filter)
 {
     TALLOC_CTX *tmp_ctx = NULL;
     char *dn_filter;
+    const char *fqname;
     errno_t ret;
 
     if (ts_res->count == 0) {
@@ -793,8 +828,16 @@ static errno_t sysdb_enum_dn_filter(TALLOC_CTX *mem_ctx,
         return ENOMEM;
     }
 
-    dn_filter = talloc_asprintf(tmp_ctx, "(&(%s=%s)(|", SYSDB_NAME,
-                                name_filter);
+    if (name_filter == NULL) {
+        dn_filter = talloc_asprintf(tmp_ctx, "(|");
+    } else {
+        fqname = sss_create_internal_fqname(tmp_ctx, name_filter, domain);
+        if (fqname == NULL) {
+            ret = ENOMEM;
+            goto done;
+        }
+        dn_filter = talloc_asprintf(tmp_ctx, "(&(%s=%s)(|", SYSDB_NAME, fqname);
+    }
     if (dn_filter == NULL) {
         ret = ENOMEM;
         goto done;
@@ -812,7 +855,7 @@ static errno_t sysdb_enum_dn_filter(TALLOC_CTX *mem_ctx,
         }
     }
 
-    dn_filter = talloc_asprintf_append(dn_filter, "))");
+    dn_filter = talloc_asprintf_append(dn_filter, (name_filter == NULL ? ")" : "))"));
     if (dn_filter == NULL) {
         ret = ENOMEM;
         goto done;
@@ -828,7 +871,8 @@ done:
 
 int sysdb_enumpwent_filter(TALLOC_CTX *mem_ctx,
                            struct sss_domain_info *domain,
-                           const char *name_filter,
+                           const char *attr,
+                           const char *attr_filter,
                            const char *addtl_filter,
                            struct ldb_result **_res)
 {
@@ -840,7 +884,7 @@ int sysdb_enumpwent_filter(TALLOC_CTX *mem_ctx,
     struct ldb_dn *base_dn;
     struct ldb_result *res;
     struct ldb_result ts_res;
-    struct ldb_result *ts_cache_res;
+    struct ldb_result *ts_cache_res = NULL;
     int ret;
 
     tmp_ctx = talloc_new(NULL);
@@ -854,38 +898,47 @@ int sysdb_enumpwent_filter(TALLOC_CTX *mem_ctx,
         goto done;
     }
 
-    ts_filter = enum_filter(tmp_ctx, SYSDB_PWENT_FILTER,
-                            NULL, addtl_filter);
-    if (ts_filter == NULL) {
-        ret = ENOMEM;
-        goto done;
-    }
-    DEBUG(SSSDBG_TRACE_LIBS, "Searching timestamp cache with [%s]\n", ts_filter);
+    /* Do not look for the user's attribute in the timestamp db as it could
+     * not be present. Only look for the name. */
+    if (attr == NULL || is_sysdb_name(attr)) {
+        ts_filter = enum_filter(tmp_ctx, SYSDB_PWENT_FILTER,
+                                NULL, NULL, NULL, addtl_filter);
+        if (ts_filter == NULL) {
+            ret = ENOMEM;
+            goto done;
+        }
+        DEBUG(SSSDBG_TRACE_LIBS, "Searching timestamp cache with [%s]\n",
+              ts_filter);
 
-    ret = sysdb_search_ts_users(tmp_ctx, domain, ts_filter,
-                                sysdb_ts_cache_attrs,
-                                &ts_res);
-    if (ret == ERR_NO_TS) {
-        ret = ENOENT;
-    }
+        ret = sysdb_search_ts_users(tmp_ctx, domain, ts_filter,
+                                    sysdb_ts_cache_attrs,
+                                    &ts_res);
+        if (ret == ERR_NO_TS) {
+            ret = ENOENT;
+        }
 
-    if (ret != EOK && ret != ENOENT) {
-        goto done;
-    }
+        if (ret != EOK && ret != ENOENT) {
+            goto done;
+        }
 
-    ret = sysdb_enum_dn_filter(tmp_ctx, &ts_res, name_filter, &dn_filter);
-    if (ret != EOK) {
-        goto done;
-    }
+        ret = sysdb_enum_dn_filter(tmp_ctx, &ts_res, attr_filter, domain->name,
+                                   &dn_filter);
+        if (ret != EOK) {
+            goto done;
+        }
 
-    ret = sysdb_search_ts_matches(tmp_ctx, domain->sysdb, attrs, &ts_res,
-                                  dn_filter, &ts_cache_res);
-    if (ret != EOK && ret != ENOENT) {
-        goto done;
+        DEBUG(SSSDBG_TRACE_LIBS, "Searching timestamp entries with [%s]\n",
+              dn_filter);
+
+        ret = sysdb_search_ts_matches(tmp_ctx, domain->sysdb, attrs, &ts_res,
+                                      dn_filter, &ts_cache_res);
+        if (ret != EOK && ret != ENOENT) {
+            goto done;
+        }
     }
 
     filter = enum_filter(tmp_ctx, SYSDB_PWENT_FILTER,
-                         name_filter, addtl_filter);
+                         attr, attr_filter, domain->name, addtl_filter);
     if (filter == NULL) {
         ret = ENOMEM;
         goto done;
@@ -907,10 +960,12 @@ int sysdb_enumpwent_filter(TALLOC_CTX *mem_ctx,
         ret = EOK;
     }
 
-    res = sss_merge_ldb_results(res, ts_cache_res);
-    if (res == NULL) {
-        ret = ENOMEM;
-        goto done;
+    if (ts_cache_res != NULL) {
+        res = sss_merge_ldb_results(res, ts_cache_res);
+        if (res == NULL) {
+            ret = ENOMEM;
+            goto done;
+        }
     }
 
     *_res = talloc_steal(mem_ctx, res);
@@ -924,12 +979,13 @@ int sysdb_enumpwent(TALLOC_CTX *mem_ctx,
                     struct sss_domain_info *domain,
                     struct ldb_result **_res)
 {
-    return sysdb_enumpwent_filter(mem_ctx, domain, NULL, 0, _res);
+    return sysdb_enumpwent_filter(mem_ctx, domain, NULL, NULL, NULL, _res);
 }
 
 int sysdb_enumpwent_filter_with_views(TALLOC_CTX *mem_ctx,
                                       struct sss_domain_info *domain,
-                                      const char *name_filter,
+                                      const char *attr,
+                                      const char *attr_filter,
                                       const char *addtl_filter,
                                       struct ldb_result **_res)
 {
@@ -944,7 +1000,8 @@ int sysdb_enumpwent_filter_with_views(TALLOC_CTX *mem_ctx,
         return ENOMEM;
     }
 
-    ret = sysdb_enumpwent_filter(tmp_ctx, domain, name_filter, addtl_filter, &res);
+    ret = sysdb_enumpwent_filter(tmp_ctx, domain, attr, attr_filter,
+                                 addtl_filter, &res);
     if (ret != EOK) {
         DEBUG(SSSDBG_OP_FAILURE, "sysdb_enumpwent failed.\n");
         goto done;
@@ -974,7 +1031,7 @@ int sysdb_enumpwent_with_views(TALLOC_CTX *mem_ctx,
                                struct sss_domain_info *domain,
                                struct ldb_result **_res)
 {
-    return sysdb_enumpwent_filter_with_views(mem_ctx, domain, NULL, NULL, _res);
+    return sysdb_enumpwent_filter_with_views(mem_ctx, domain, NULL, NULL, NULL, _res);
 }
 
 /* groups */
@@ -1459,7 +1516,7 @@ int sysdb_enumgrent_filter(TALLOC_CTX *mem_ctx,
     }
 
     ts_filter = enum_filter(tmp_ctx, base_filter,
-                            NULL, addtl_filter);
+                            NULL, NULL, NULL, addtl_filter);
     if (ts_filter == NULL) {
         ret = ENOMEM;
         goto done;
@@ -1477,7 +1534,8 @@ int sysdb_enumgrent_filter(TALLOC_CTX *mem_ctx,
         goto done;
     }
 
-    ret = sysdb_enum_dn_filter(tmp_ctx, &ts_res, name_filter, &dn_filter);
+    ret = sysdb_enum_dn_filter(tmp_ctx, &ts_res, name_filter, domain->name,
+                               &dn_filter);
     if (ret != EOK) {
         goto done;
     }
@@ -1489,7 +1547,7 @@ int sysdb_enumgrent_filter(TALLOC_CTX *mem_ctx,
     }
 
     filter = enum_filter(tmp_ctx, base_filter,
-                         name_filter, addtl_filter);
+                         SYSDB_NAME, name_filter, domain->name, addtl_filter);
     if (filter == NULL) {
         ret = ENOMEM;
         goto done;
