@@ -200,8 +200,12 @@ struct dp_option {
 
 #define DP_OPTION_TERMINATOR { NULL, 0, NULL_STRING, NULL_STRING }
 
-void dp_option_inherit(char **inherit_opt_list,
-                       int option,
+void dp_option_inherit_match(char **inherit_opt_list,
+                             int option,
+                             struct dp_option *parent_opts,
+                             struct dp_option *subdom_opts);
+
+void dp_option_inherit(int option,
                        struct dp_option *parent_opts,
                        struct dp_option *subdom_opts);
 
@@ -259,6 +263,7 @@ enum dp_res_opts {
     DP_RES_OPT_RESOLVER_TIMEOUT,
     DP_RES_OPT_RESOLVER_OP_TIMEOUT,
     DP_RES_OPT_RESOLVER_SERVER_TIMEOUT,
+    DP_RES_OPT_RESOLVER_USE_SEARCH_LIST,
     DP_RES_OPT_DNS_DOMAIN,
 
     DP_RES_OPTS /* attrs counter */
