@@ -27,13 +27,6 @@
 
 #include "providers/ldap/ldap_common.h"
 
-#ifdef HAVE_SELINUX_LOGIN_DIR
-
-#define ALL_SERVICES "*"
-#define selogin_path(mem_ctx, username) \
-    talloc_asprintf(mem_ctx, "%s/logins/%s", selinux_policy_root(), username)
-#endif /* HAVE_SELINUX_LOGIN_DIR */
-
 struct ipa_selinux_ctx {
     struct ipa_id_ctx *id_ctx;
     time_t last_update;
@@ -43,6 +36,15 @@ struct ipa_selinux_ctx {
     struct sdap_search_base **hbac_search_bases;
 };
 
-void ipa_selinux_handler(struct be_req *be_req);
+struct tevent_req *
+ipa_selinux_handler_send(TALLOC_CTX *mem_ctx,
+                         struct ipa_selinux_ctx *selinux_ctx,
+                         struct pam_data *pd,
+                         struct dp_req_params *params);
+
+errno_t
+ipa_selinux_handler_recv(TALLOC_CTX *mem_ctx,
+                         struct tevent_req *req,
+                         struct pam_data **_data);
 
 #endif
