@@ -43,8 +43,8 @@ struct ldap_init_ctx {
 };
 
 /* Please use this only for short lists */
-errno_t check_order_list_for_duplicates(char **list,
-                                        bool case_sensitive)
+static errno_t check_order_list_for_duplicates(char **list,
+                                               bool case_sensitive)
 {
     size_t c;
     size_t d;
@@ -396,6 +396,8 @@ static errno_t ldap_init_misc(struct be_ctx *be_ctx,
         }
     }
 
+    setup_ldap_debug(options->basic);
+
     ret = setup_tls_config(options->basic);
     if (ret != EOK) {
         DEBUG(SSSDBG_CRIT_FAILURE, "Unable to get TLS options [%d]: %s\n",
