@@ -39,22 +39,6 @@ typedef void (sdap_op_callback_t)(struct sdap_op *op,
 
 struct sdap_handle;
 
-struct sdap_op {
-    struct sdap_op *prev, *next;
-    struct sdap_handle *sh;
-    uint64_t chain_id;
-
-    int msgid;
-    bool done;
-
-    sdap_op_callback_t *callback;
-    void *data;
-
-    struct tevent_context *ev;
-    struct sdap_msg *list;
-    struct sdap_msg *last;
-};
-
 struct fd_event_item {
     struct fd_event_item *prev;
     struct fd_event_item *next;
@@ -79,6 +63,10 @@ struct sdap_handle {
     bool connected;
     /* Authentication ticket expiration time (if any) */
     time_t expire_time;
+    /* Time when the connection became idle (if any) */
+    time_t idle_time;
+    /* Configured idle timeout */
+    int idle_timeout;
     ber_int_t page_size;
     bool disable_deref;
 
@@ -184,7 +172,9 @@ enum sdap_basic_opt {
     SDAP_OFFLINE_TIMEOUT,
     SDAP_FORCE_UPPER_CASE_REALM,
     SDAP_ENUM_REFRESH_TIMEOUT,
+    SDAP_ENUM_REFRESH_OFFSET,
     SDAP_PURGE_CACHE_TIMEOUT,
+    SDAP_PURGE_CACHE_OFFSET,
     SDAP_TLS_CACERT,
     SDAP_TLS_CACERTDIR,
     SDAP_TLS_CERT,
@@ -224,9 +214,11 @@ enum sdap_basic_opt {
     SDAP_DISABLE_AUTH_TLS,
     SDAP_PAGE_SIZE,
     SDAP_DEREF_THRESHOLD,
+    SDAP_IGNORE_UNREADABLE_REFERENCES,
     SDAP_SASL_CANONICALIZE,
     SDAP_EXPIRE_TIMEOUT,
     SDAP_EXPIRE_OFFSET,
+    SDAP_IDLE_TIMEOUT,
     SDAP_DISABLE_PAGING,
     SDAP_IDMAP_LOWER,
     SDAP_IDMAP_UPPER,
@@ -688,12 +680,28 @@ errno_t sdap_get_user_primary_name(TALLOC_CTX *memctx,
                                    struct sss_domain_info *dom,
                                    const char **_user_name);
 
-errno_t sdap_get_netgroup_primary_name(TALLOC_CTX *memctx,
-                                       struct sdap_options *opts,
+errno_t sdap_get_netgroup_primary_name(struct sdap_options *opts,
                                        struct sysdb_attrs *attrs,
-                                       struct sss_domain_info *dom,
                                        const char **_netgroup_name);
 
+errno_t sdap_get_primary_name(const char *attr_name,
+                              struct sysdb_attrs *attrs,
+                              const char **_primary_name);
+
+errno_t sdap_get_primary_name_list(struct sss_domain_info *domain,
+                                   TALLOC_CTX *mem_ctx,
+                                   struct sysdb_attrs **attr_list,
+                                   size_t attr_count,
+                                   const char *ldap_attr,
+                                   char ***name_list);
+
+errno_t sdap_get_primary_fqdn_list(struct sss_domain_info *domain,
+                                   TALLOC_CTX *mem_ctx,
+                                   struct sysdb_attrs **attr_list,
+                                   size_t attr_count,
+                                   const char *ldap_attr,
+                                   char ***name_list);
+
 errno_t sdap_set_config_options_with_rootdse(struct sysdb_attrs *rootdse,
                                              struct sdap_options *opts,
                                              struct sdap_domain *sdom);
