@@ -29,6 +29,30 @@
 
 #define REPLY_REALLOC_INCREMENT 10
 
+struct sdap_op {
+    struct sdap_op *prev, *next;
+    struct sdap_handle *sh;
+    uint64_t chain_id;
+
+    int msgid;
+    char *stat_info;
+    uint64_t start_time;
+    int timeout;
+    bool done;
+
+    sdap_op_callback_t *callback;
+    void *data;
+
+    struct tevent_context *ev;
+    struct sdap_msg *list;
+    struct sdap_msg *last;
+};
+
+int sdap_op_get_msgid(struct sdap_op *op)
+{
+    return op != NULL ? op->msgid : 0;
+}
+
 /* ==LDAP-Memory-Handling================================================= */
 
 static int lmsg_destructor(void *mem)
@@ -69,6 +93,33 @@ static int sdap_handle_destructor(void *mem)
     return 0;
 }
 
+static void sdap_call_op_callback(struct sdap_op *op, struct sdap_msg *reply,
+                                  int error)
+{
+    uint64_t time_spend;
+    const char *info = (op->stat_info == NULL ? "-" : op->stat_info);
+
+    if (op->start_time != 0) {
+        time_spend = get_spend_time_us(op->start_time);
+        DEBUG(SSSDBG_PERF_STAT,
+              "Handling LDAP operation [%d][%s] took %s.\n",
+              op->msgid, info, sss_format_time(time_spend));
+
+        /* time_spend is in us and timeout in s */
+        if (op->timeout != 0 && (time_spend / op->timeout) >= (80 * 10000)) {
+            DEBUG(SSSDBG_IMPORTANT_INFO, "LDAP operation [%d][%s] seems slow, "
+                                         "took more than 80%% of timeout [%d].\n",
+                                         op->msgid, info, op->timeout);
+        }
+
+        /* Avoid multiple outputs for the same operation if multiple results
+         * are returned */
+        op->start_time = 0;
+    }
+
+    op->callback(op, reply, error, op->data);
+}
+
 static void sdap_handle_release(struct sdap_handle *sh)
 {
     struct sdap_op *op;
@@ -89,7 +140,7 @@ static void sdap_handle_release(struct sdap_handle *sh)
 
     while (sh->ops) {
         op = sh->ops;
-        op->callback(op, NULL, EIO, op->data);
+        sdap_call_op_callback(op, NULL, EIO);
         /* calling the callback may result in freeing the op */
         /* check if it is still the same or avoid freeing */
         if (op == sh->ops) talloc_free(op);
@@ -364,7 +415,7 @@ static void sdap_process_message(struct tevent_context *ev,
 
         /* must be the last operation as it may end up freeing all memory
          * including all ops handlers */
-        op->callback(op, reply, ret, op->data);
+        sdap_call_op_callback(op, reply, ret);
     }
 }
 
@@ -397,7 +448,7 @@ static void sdap_unlock_next_reply(struct sdap_op *op)
         if (!te) {
             DEBUG(SSSDBG_CRIT_FAILURE,
                   "Failed to add critical timer for next reply!\n");
-            op->callback(op, NULL, EFAULT, op->data);
+            sdap_call_op_callback(op, NULL, EFAULT);
         }
     }
 }
@@ -408,7 +459,7 @@ static void sdap_process_next_reply(struct tevent_context *ev,
 {
     struct sdap_op *op = talloc_get_type(pvt, struct sdap_op);
 
-    op->callback(op, op->list, EOK, op->data);
+    sdap_call_op_callback(op, op->list, EOK);
 }
 
 /* ==LDAP-Operations-Helpers============================================== */
@@ -446,11 +497,11 @@ static void sdap_op_timeout(struct tevent_req *req)
 
     /* signal the caller that we have a timeout */
     DEBUG(SSSDBG_TRACE_LIBS, "Issuing timeout [ldap_opt_timeout] for message id %d\n", op->msgid);
-    op->callback(op, NULL, ETIMEDOUT, op->data);
+    sdap_call_op_callback(op, NULL, ETIMEDOUT);
 }
 
 int sdap_op_add(TALLOC_CTX *memctx, struct tevent_context *ev,
-                struct sdap_handle *sh, int msgid,
+                struct sdap_handle *sh, int msgid, const char *stat_info,
                 sdap_op_callback_t *callback, void *data,
                 int timeout, struct sdap_op **_op)
 {
@@ -459,8 +510,16 @@ int sdap_op_add(TALLOC_CTX *memctx, struct tevent_context *ev,
     op = talloc_zero(memctx, struct sdap_op);
     if (!op) return ENOMEM;
 
+    op->start_time = get_start_time();
+    op->timeout = timeout;
     op->sh = sh;
     op->msgid = msgid;
+    if (stat_info != NULL) {
+        op->stat_info = talloc_strdup(op, stat_info);
+        if (op->stat_info == NULL) {
+            DEBUG(SSSDBG_OP_FAILURE, "Failed to copy stat_info, ignored.\n");
+        }
+    }
     op->callback = callback;
     op->data = data;
     op->ev = ev;
@@ -558,6 +617,7 @@ struct tevent_req *sdap_exop_modify_passwd_send(TALLOC_CTX *memctx,
     int msgid;
     LDAPControl **request_controls = NULL;
     LDAPControl *ctrls[2] = { NULL, NULL };
+    char *stat_info;
 
     req = tevent_req_create(memctx, &state,
                             struct sdap_exop_modify_passwd_state);
@@ -616,7 +676,14 @@ struct tevent_req *sdap_exop_modify_passwd_send(TALLOC_CTX *memctx,
     DEBUG(SSSDBG_TRACE_INTERNAL,
           "ldap_extended_operation sent, msgid = %d\n", msgid);
 
-    ret = sdap_op_add(state, ev, state->sh, msgid,
+    stat_info = talloc_asprintf(state, "server: [%s] modify passwd dn: [%s]",
+                                sdap_get_server_ip_str_safe(state->sh),
+                                user_dn);
+    if (stat_info == NULL) {
+        DEBUG(SSSDBG_OP_FAILURE, "Failed to create info string, ignored.\n");
+    }
+
+    ret = sdap_op_add(state, ev, state->sh, msgid, stat_info,
                       sdap_exop_modify_passwd_done, req, timeout, &state->op);
     if (ret) {
         DEBUG(SSSDBG_CRIT_FAILURE, "Failed to set up operation!\n");
@@ -748,6 +815,7 @@ sdap_modify_send(TALLOC_CTX *mem_ctx,
     LDAPMod **mods;
     errno_t ret;
     int msgid;
+    char *stat_info;
 
     req = tevent_req_create(mem_ctx, &state, struct sdap_modify_state);
     if (req == NULL) {
@@ -780,7 +848,14 @@ sdap_modify_send(TALLOC_CTX *mem_ctx,
         goto done;
     }
 
-    ret = sdap_op_add(state, state->ev, state->sh, msgid,
+    stat_info = talloc_asprintf(state, "server: [%s] modify dn: [%s] attr: [%s]",
+                                sdap_get_server_ip_str_safe(state->sh), dn,
+                                attr);
+    if (stat_info == NULL) {
+        DEBUG(SSSDBG_OP_FAILURE, "Failed to create info string, ignored.\n");
+    }
+
+    ret = sdap_op_add(state, state->ev, state->sh, msgid, stat_info,
                       sdap_modify_done, req, timeout, &state->op);
     if (ret) {
         DEBUG(SSSDBG_CRIT_FAILURE, "Failed to set up operation!\n");
@@ -1264,7 +1339,7 @@ static errno_t add_to_deref_reply(TALLOC_CTX *mem_ctx,
     return EOK;
 }
 
-static void sdap_print_server(struct sdap_handle *sh)
+const char *sdap_get_server_ip_str(struct sdap_handle *sh)
 {
     int ret;
     int fd;
@@ -1272,38 +1347,67 @@ static void sdap_print_server(struct sdap_handle *sh)
     socklen_t ss_len = sizeof(ss);
     struct sockaddr *s_addr = (struct sockaddr *)&ss;
     char ip[NI_MAXHOST];
+    static char out[NI_MAXHOST + 8];
     int port;
 
     ret = get_fd_from_ldap(sh->ldap, &fd);
     if (ret != EOK) {
         DEBUG(SSSDBG_MINOR_FAILURE, "cannot get sdap fd\n");
-        return;
+        return NULL;
     }
 
     ret = getpeername(fd, s_addr, &ss_len);
     if (ret == -1) {
         DEBUG(SSSDBG_MINOR_FAILURE, "getsockname failed\n");
-        return;
+        return NULL;
     }
 
     ret = getnameinfo(s_addr, ss_len,
                       ip, sizeof(ip), NULL, 0, NI_NUMERICHOST);
     if (ret != 0) {
         DEBUG(SSSDBG_MINOR_FAILURE, "getnameinfo failed\n");
-        return;
+        return NULL;
     }
 
     switch (s_addr->sa_family) {
     case AF_INET:
         port = ntohs(((struct sockaddr_in *)s_addr)->sin_port);
-        DEBUG(SSSDBG_TRACE_INTERNAL, "Searching %s:%d\n", ip, port);
+        ret = snprintf(out, sizeof(out), "%s:%d", ip, port);
         break;
     case AF_INET6:
         port = ntohs(((struct sockaddr_in6 *)s_addr)->sin6_port);
-        DEBUG(SSSDBG_TRACE_INTERNAL, "Searching %s:%d\n", ip, port);
+        ret = snprintf(out, sizeof(out), "[%s]:%d", ip, port);
         break;
     default:
-        DEBUG(SSSDBG_TRACE_INTERNAL, "Searching %s\n", ip);
+        ret = snprintf(out, sizeof(out), "%s", ip);
+    }
+
+    if (ret < 0 || ret >= sizeof(out)) {
+        return NULL;
+    }
+
+    return out;
+}
+
+const char *sdap_get_server_ip_str_safe(struct sdap_handle *sh)
+{
+    const char *ip = sdap_get_server_ip_str(sh);
+    return ip != NULL ? ip : "- IP not available -";
+}
+
+static void sdap_print_server(struct sdap_handle *sh)
+{
+    const char *ip;
+
+    /* The purpose of the call is to add the server IP to the debug output if
+     * debug_level is SSSDBG_TRACE_INTERNAL or higher */
+    if (DEBUG_IS_SET(SSSDBG_TRACE_INTERNAL)) {
+        ip = sdap_get_server_ip_str(sh);
+        if (ip != NULL) {
+            DEBUG(SSSDBG_TRACE_INTERNAL, "Searching %s\n", ip);
+        } else {
+            DEBUG(SSSDBG_OP_FAILURE, "sdap_get_server_ip_str failed.\n");
+        }
     }
 }
 
@@ -1480,6 +1584,7 @@ static errno_t sdap_get_generic_ext_step(struct tevent_req *req)
     errno_t ret;
     int msgid;
     bool disable_paging;
+    char *stat_info;
 
     LDAPControl *page_control = NULL;
 
@@ -1552,7 +1657,14 @@ static errno_t sdap_get_generic_ext_step(struct tevent_req *req)
     }
     DEBUG(SSSDBG_TRACE_INTERNAL, "ldap_search_ext called, msgid = %d\n", msgid);
 
-    ret = sdap_op_add(state, state->ev, state->sh, msgid,
+    stat_info = talloc_asprintf(state, "server: [%s] filter: [%s] base: [%s]",
+                                sdap_get_server_ip_str_safe(state->sh),
+                                state->filter, state->search_base);
+    if (stat_info == NULL) {
+        DEBUG(SSSDBG_OP_FAILURE, "Failed to create info string, ignored.\n");
+    }
+
+    ret = sdap_op_add(state, state->ev, state->sh, msgid, stat_info,
                       sdap_get_generic_op_finished, req,
                       state->timeout,
                       &state->op);
@@ -2012,6 +2124,7 @@ struct tevent_req *sdap_get_generic_send(TALLOC_CTX *memctx,
                                              false, NULL, NULL, 0, timeout,
                                              allow_paging);
     if (subreq == NULL) {
+        talloc_zfree(req);
         return NULL;
     }
     tevent_req_set_callback(subreq, sdap_get_generic_done, req);
@@ -2070,6 +2183,7 @@ struct sdap_x_deref_search_state {
     struct sdap_attr_map_info *maps;
     LDAPControl **ctrls;
     struct sdap_options *opts;
+    bool ldap_ignore_unreadable_references;
 
     struct sdap_deref_reply dreply;
     int num_maps;
@@ -2104,6 +2218,9 @@ sdap_x_deref_search_send(TALLOC_CTX *memctx, struct tevent_context *ev,
     talloc_set_destructor((TALLOC_CTX *) state->ctrls,
                           sdap_x_deref_search_ctrls_destructor);
 
+    state->ldap_ignore_unreadable_references = dp_opt_get_bool(opts->basic,
+                                            SDAP_IGNORE_UNREADABLE_REFERENCES);
+
     ret = sdap_x_deref_create_control(sh, deref_attr,
                                       attrs, &state->ctrls[0]);
     if (ret != EOK) {
@@ -2243,6 +2360,13 @@ static errno_t sdap_x_deref_parse_entry(struct sdap_handle *sh,
 
     ret = EOK;
 done:
+    if (ret != EOK && ret != ENOMEM) {
+        if (state->ldap_ignore_unreadable_references) {
+            DEBUG(SSSDBG_TRACE_FUNC, "Ignoring unreadable reference\n");
+            ret = EOK;
+        }
+    }
+
     talloc_zfree(tmp_ctx);
     ldap_controls_free(ctrls);
     ldap_derefresponse_free(deref_res);
@@ -2500,6 +2624,7 @@ struct sdap_asq_search_state {
     int num_maps;
     LDAPControl **ctrls;
     struct sdap_options *opts;
+    bool ldap_ignore_unreadable_references;
 
     struct sdap_deref_reply dreply;
 };
@@ -2539,6 +2664,9 @@ sdap_asq_search_send(TALLOC_CTX *memctx, struct tevent_context *ev,
     talloc_set_destructor((TALLOC_CTX *) state->ctrls,
                           sdap_asq_search_ctrls_destructor);
 
+    state->ldap_ignore_unreadable_references = dp_opt_get_bool(opts->basic,
+                                            SDAP_IGNORE_UNREADABLE_REFERENCES);
+
     ret = sdap_asq_search_create_control(sh, deref_attr, &state->ctrls[0]);
     if (ret != EOK) {
         talloc_zfree(req);
@@ -2610,10 +2738,10 @@ static errno_t sdap_asq_search_parse_entry(struct sdap_handle *sh,
     struct berval **vals;
     int i, mi;
     struct sdap_attr_map *map;
-    int num_attrs;
+    int num_attrs = 0;
     struct sdap_deref_attrs **res;
     char *tmp;
-    char *dn;
+    char *dn = NULL;
     TALLOC_CTX *tmp_ctx;
     bool disable_range_rtrvl;
 
@@ -2704,6 +2832,13 @@ static errno_t sdap_asq_search_parse_entry(struct sdap_handle *sh,
 
     ret = EOK;
 done:
+    if (ret != EOK && ret != ENOMEM) {
+        if (state->ldap_ignore_unreadable_references) {
+            DEBUG(SSSDBG_TRACE_FUNC, "Ignoring unreadable reference [%s]\n",
+                  dn != NULL ? dn : "(null)");
+            ret = EOK;
+        }
+    }
     talloc_zfree(tmp_ctx);
     return ret;
 }
