@@ -30,6 +30,8 @@
 #include "providers/ldap/sdap_async_private.h"
 #include "providers/ldap/ldap_common.h"
 
+#define MAX_RETRY_ATTEMPTS 1
+
 /* ==Connect-to-LDAP-Server=============================================== */
 
 struct sdap_rebind_proc_params {
@@ -134,7 +136,7 @@ static void sdap_sys_connect_done(struct tevent_req *subreq)
                                                      struct sdap_connect_state);
     struct timeval tv;
     int ver;
-    int lret;
+    int lret = 0;
     int optret;
     int ret = EOK;
     int msgid;
@@ -150,6 +152,7 @@ static void sdap_sys_connect_done(struct tevent_req *subreq)
     ber_len_t ber_sasl_minssf;
     int sasl_maxssf;
     ber_len_t ber_sasl_maxssf;
+    char *stat_info;
 
     ret = sss_ldap_init_recv(subreq, &state->sh->ldap, &sd);
     talloc_zfree(subreq);
@@ -335,10 +338,16 @@ static void sdap_sys_connect_done(struct tevent_req *subreq)
         goto fail;
     }
 
+    stat_info = talloc_asprintf(state, "server: [%s] START TLS",
+                                sdap_get_server_ip_str_safe(state->sh));
+    if (stat_info == NULL) {
+        DEBUG(SSSDBG_OP_FAILURE, "Failed to create info string, ignored.\n");
+    }
+
     ret = sdap_set_connected(state->sh, state->ev);
     if (ret) goto fail;
 
-    ret = sdap_op_add(state, state->ev, state->sh, msgid,
+    ret = sdap_op_add(state, state->ev, state->sh, msgid, stat_info,
                       sdap_connect_done, req,
                       dp_opt_get_int(state->opts->basic, SDAP_OPT_TIMEOUT),
                       &state->op);
@@ -385,7 +394,7 @@ static void sdap_connect_done(struct sdap_op *op,
                             &state->result, NULL, &errmsg, NULL, NULL, 0);
     if (ret != LDAP_SUCCESS) {
         DEBUG(SSSDBG_OP_FAILURE,
-              "ldap_parse_result failed (%d)\n", state->op->msgid);
+              "ldap_parse_result failed (%d)\n", sdap_op_get_msgid(state->op));
         tevent_req_error(req, EIO);
         return;
     }
@@ -518,11 +527,7 @@ struct tevent_req *sdap_connect_host_send(TALLOC_CTX *mem_ctx,
     return req;
 
 immediately:
-    if (ret == EOK) {
-        tevent_req_done(req);
-    } else {
-        tevent_req_error(req, ret);
-    }
+    tevent_req_error(req, ret);
     tevent_req_post(req, ev);
 
     return req;
@@ -660,6 +665,7 @@ static struct tevent_req *simple_bind_send(TALLOC_CTX *memctx,
     int ldap_err;
     LDAPControl **request_controls = NULL;
     LDAPControl *ctrls[2] = { NULL, NULL };
+    char *stat_info;
 
     req = tevent_req_create(memctx, &state, struct simple_bind_state);
     if (!req) return NULL;
@@ -710,7 +716,14 @@ static struct tevent_req *simple_bind_send(TALLOC_CTX *memctx,
         if (ret) goto fail;
     }
 
-    ret = sdap_op_add(state, ev, sh, msgid,
+    stat_info = talloc_asprintf(state, "server: [%s] simple bind: [%s]",
+                                sdap_get_server_ip_str_safe(state->sh),
+                                state->user_dn);
+    if (stat_info == NULL) {
+        DEBUG(SSSDBG_OP_FAILURE, "Failed to create info string, ignored.\n");
+    }
+
+    ret = sdap_op_add(state, ev, sh, msgid, stat_info,
                       simple_bind_done, req, timeout, &state->op);
     if (ret) {
         DEBUG(SSSDBG_CRIT_FAILURE, "Failed to set up operation!\n");
@@ -760,7 +773,7 @@ static void simple_bind_done(struct sdap_op *op,
                             &response_controls, 0);
     if (lret != LDAP_SUCCESS) {
         DEBUG(SSSDBG_MINOR_FAILURE,
-              "ldap_parse_result failed (%d)\n", state->op->msgid);
+              "ldap_parse_result failed (%d)\n", sdap_op_get_msgid(state->op));
         ret = ERR_INTERNAL;
         goto done;
     }
@@ -1273,9 +1286,15 @@ static void sdap_kinit_done(struct tevent_req *subreq)
         }
 
     }
-
-    DEBUG(SSSDBG_CONF_SETTINGS,
-          "Could not get TGT: %d [%s]\n", result, sss_strerror(result));
+    if (result == EFAULT || result == EIO || result == EPERM) {
+        DEBUG(SSSDBG_CONF_SETTINGS,
+              "Could not get TGT from server %s: %d [%s]\n",
+              state->kdc_srv ? fo_get_server_name(state->kdc_srv) : "NULL",
+              result, sss_strerror(result));
+    } else {
+        DEBUG(SSSDBG_CONF_SETTINGS,
+              "Could not get TGT: %d [%s]\n", result, sss_strerror(result));
+    }
     tevent_req_error(req, ERR_AUTH_FAILED);
 }
 
@@ -1448,6 +1467,8 @@ struct sdap_cli_connect_state {
     enum connect_tls force_tls;
     bool do_auth;
     bool use_tls;
+
+    int retry_attempts;
 };
 
 static int sdap_cli_resolve_next(struct tevent_req *req);
@@ -1600,16 +1621,37 @@ static void sdap_cli_connect_done(struct tevent_req *subreq)
     talloc_zfree(state->sh);
     ret = sdap_connect_recv(subreq, state, &state->sh);
     talloc_zfree(subreq);
-    if (ret) {
+    if (ret == ERR_TLS_HANDSHAKE_INTERRUPTED &&
+        state->retry_attempts < MAX_RETRY_ATTEMPTS) {
+        DEBUG(SSSDBG_OP_FAILURE,
+              "TLS handshake was interruped, provider will retry\n");
+        state->retry_attempts++;
+        subreq = sdap_connect_send(state, state->ev, state->opts,
+                                   state->service->uri,
+                                   state->service->sockaddr,
+                                   state->use_tls);
+
+        if (!subreq) {
+            tevent_req_error(req, ENOMEM);
+            return;
+        }
+
+        tevent_req_set_callback(subreq, sdap_cli_connect_done, req);
+        return;
+    } else if (ret != EOK) {
+        state->retry_attempts = 0;
         /* retry another server */
         be_fo_set_port_status(state->be, state->service->name,
                               state->srv, PORT_NOT_WORKING);
+
         ret = sdap_cli_resolve_next(req);
         if (ret != EOK) {
             tevent_req_error(req, ret);
         }
+
         return;
     }
+    state->retry_attempts = 0;
 
     if (state->use_rootdse) {
         /* fetch the rootDSE this time */
