@@ -209,13 +209,9 @@ static errno_t sdap_nested_group_hash_insert(hash_table_t *table,
                              entry_key, table_name);
 
     key.type = HASH_KEY_STRING;
-    key.str = talloc_strdup(NULL, entry_key);
-    if (key.str == NULL) {
-        return ENOMEM;
-    }
+    key.c_str = discard_const(entry_key); /* hash_enter() will make a copy */
 
     if (overwrite == false && hash_has_key(table, &key)) {
-        talloc_free(key.str);
         return EEXIST;
     }
 
@@ -224,11 +220,9 @@ static errno_t sdap_nested_group_hash_insert(hash_table_t *table,
 
     hret = hash_enter(table, &key, &value);
     if (hret != HASH_SUCCESS) {
-        talloc_free(key.str);
         return EIO;
     }
 
-    talloc_steal(table, key.str);
     talloc_steal(table, value.ptr);
 
     return EOK;
@@ -264,7 +258,7 @@ sdap_nested_group_hash_group(struct sdap_nested_group_ctx *group_ctx,
                              struct sysdb_attrs *group)
 {
     struct sdap_attr_map *map = group_ctx->opts->group_map;
-    gid_t gid;
+    gid_t gid = 0;
     errno_t ret;
     bool posix_group = true;
     bool use_id_mapping;
@@ -1355,6 +1349,7 @@ struct sdap_nested_group_single_state {
 
     struct sysdb_attrs **nested_groups;
     int num_groups;
+    bool ignore_unreadable_references;
 };
 
 static errno_t sdap_nested_group_single_step(struct tevent_req *req);
@@ -1395,6 +1390,8 @@ sdap_nested_group_single_send(TALLOC_CTX *mem_ctx,
         goto immediately;
     }
     state->num_groups = 0; /* we will count exact number of the groups */
+    state->ignore_unreadable_references = dp_opt_get_bool(
+            group_ctx->opts->basic, SDAP_IGNORE_UNREADABLE_REFERENCES);
 
     /* process each member individually */
     ret = sdap_nested_group_single_step(req);
@@ -1573,7 +1570,15 @@ sdap_nested_group_single_step_process(struct tevent_req *subreq)
 
         break;
     case SDAP_NESTED_GROUP_DN_UNKNOWN:
-        /* not found in users nor nested_groups, continue */
+        if (state->ignore_unreadable_references) {
+            DEBUG(SSSDBG_TRACE_FUNC, "Ignoring unreadable reference [%s]\n",
+                  state->current_member->dn);
+        } else {
+            DEBUG(SSSDBG_OP_FAILURE, "Unknown entry type [%s]!\n",
+                  state->current_member->dn);
+            ret = EINVAL;
+            goto done;
+        }
         break;
     }
 
@@ -2061,21 +2066,13 @@ sdap_nested_group_lookup_unknown_send(TALLOC_CTX *mem_ctx,
                                                 state->member);
     if (subreq == NULL) {
         ret = ENOMEM;
-        goto immediately;
-    }
-
-    tevent_req_set_callback(subreq, sdap_nested_group_lookup_unknown_user_done,
-                            req);
-
-    return req;
-
-immediately:
-    if (ret == EOK) {
-        tevent_req_done(req);
-    } else {
         tevent_req_error(req, ret);
+        tevent_req_post(req, ev);
+    } else {
+        tevent_req_set_callback(subreq,
+                                sdap_nested_group_lookup_unknown_user_done,
+                                req);
     }
-    tevent_req_post(req, ev);
 
     return req;
 }
@@ -2293,6 +2290,49 @@ immediately:
     return req;
 }
 
+static hash_table_t *
+convert_ldb_element_to_set(const struct ldb_message_element *members)
+{
+    errno_t ret;
+    hash_table_t *set = NULL;
+    hash_key_t key;
+    hash_value_t value;
+    size_t j;
+
+    ret = sss_hash_create(NULL, members->num_values, &set);
+    if (ret != EOK) {
+        DEBUG(SSSDBG_CRIT_FAILURE, "Unable to create hash table [%d]: %s\n",
+                                    ret, strerror(ret));
+        return NULL;
+    }
+
+    key.type = HASH_KEY_CONST_STRING;
+    value.type = HASH_VALUE_UNDEF;
+
+    for (j = 0; j < members->num_values; ++j) {
+        key.c_str = (const char*)members->values[j].data;
+        /* since hash table is used as a set, we don't care about value */
+        ret = hash_enter(set, &key, &value);
+        if (ret != HASH_SUCCESS) {
+            DEBUG(SSSDBG_CRIT_FAILURE, "Failed to add '%s'\n", key.c_str);
+            hash_destroy(set);
+            return NULL;
+        }
+    }
+
+    return set;
+}
+
+static bool set_has_key(hash_table_t *set, const char *key)
+{
+    hash_key_t hkey;
+
+    hkey.type = HASH_KEY_CONST_STRING;
+    hkey.c_str = key;
+
+    return hash_has_key(set, &hkey);
+}
+
 static errno_t
 sdap_nested_group_deref_direct_process(struct tevent_req *subreq)
 {
@@ -2301,11 +2341,10 @@ sdap_nested_group_deref_direct_process(struct tevent_req *subreq)
     struct sdap_options *opts = NULL;
     struct sdap_deref_attrs **entries = NULL;
     struct ldb_message_element *members = NULL;
+    hash_table_t *members_set = NULL; /* will be used as a `set` */
     const char *orig_dn = NULL;
-    const char *member_dn = NULL;
     size_t num_entries = 0;
-    size_t i, j;
-    bool member_found;
+    size_t i;
     errno_t ret;
 
     req = tevent_req_callback_data(subreq, struct tevent_req);
@@ -2313,6 +2352,11 @@ sdap_nested_group_deref_direct_process(struct tevent_req *subreq)
 
     opts = state->group_ctx->opts;
     members = state->members;
+    members_set = convert_ldb_element_to_set(state->members);
+    if (members_set == NULL) {
+        ret = ENOMEM;
+        goto done;
+    }
 
     ret = sdap_deref_search_recv(subreq, state, &num_entries, &entries);
     if (ret != EOK) {
@@ -2348,17 +2392,7 @@ sdap_nested_group_deref_direct_process(struct tevent_req *subreq)
          * from deref/asq than we got from the initial lookup, as is the case
          * with Active Directory and its range retrieval mechanism.
          */
-        member_found = false;
-        for (j = 0; j < members->num_values; j++) {
-            /* FIXME: This is inefficient for very large sets of groups */
-            member_dn = (const char *)members->values[j].data;
-            if (strcasecmp(orig_dn, member_dn) == 0) {
-                member_found = true;
-                break;
-            }
-        }
-
-        if (!member_found) {
+        if (!set_has_key(members_set, orig_dn)) {
             /* Append newly found member to member list.
              * Changes in state->members will propagate into sysdb_attrs of
              * the group. */
@@ -2455,6 +2489,9 @@ sdap_nested_group_deref_direct_process(struct tevent_req *subreq)
     ret = EOK;
 
 done:
+    if (members_set != NULL) {
+        hash_destroy(members_set);
+    }
     return ret;
 }
 
