@@ -192,7 +192,6 @@ errno_t check_allowed_uids(uid_t uid, size_t allowed_uids_count,
 }
 
 errno_t csv_string_to_uid_array(TALLOC_CTX *mem_ctx, const char *csv_string,
-                                bool allow_sss_loop,
                                 size_t *_uid_count, uid_t **_uids)
 {
     int ret;
@@ -201,6 +200,19 @@ errno_t csv_string_to_uid_array(TALLOC_CTX *mem_ctx, const char *csv_string,
     int list_size;
     uid_t *uids = NULL;
     char *endptr;
+    const char *envvar;
+    bool loops_were_allowed;
+
+    envvar = getenv("_SSS_LOOPS");
+    loops_were_allowed = (envvar == NULL || strcmp(envvar, "NO") != 0);
+
+    if (!loops_were_allowed) {
+        ret = unsetenv("_SSS_LOOPS");
+        if (ret != 0) {
+            DEBUG(SSSDBG_OP_FAILURE, "Failed to unset _SSS_LOOPS.\n");
+            goto done;
+        }
+    }
 
     ret = split_on_separator(mem_ctx, csv_string, ',', true, false,
                              &list, &list_size);
@@ -217,14 +229,6 @@ errno_t csv_string_to_uid_array(TALLOC_CTX *mem_ctx, const char *csv_string,
         goto done;
     }
 
-    if (allow_sss_loop) {
-        ret = unsetenv("_SSS_LOOPS");
-        if (ret != EOK) {
-            DEBUG(SSSDBG_OP_FAILURE, "Failed to unset _SSS_LOOPS, getpwnam "
-                                      "might not find sssd users.\n");
-        }
-    }
-
     for (c = 0; c < list_size; c++) {
         if (*list[c] == '\0') {
             DEBUG(SSSDBG_OP_FAILURE, "Empty list item.\n");
@@ -260,8 +264,10 @@ errno_t csv_string_to_uid_array(TALLOC_CTX *mem_ctx, const char *csv_string,
     ret = EOK;
 
 done:
-    if(setenv("_SSS_LOOPS", "NO", 0) != 0) {
-        DEBUG(SSSDBG_OP_FAILURE, "Failed to set _SSS_LOOPS.\n");
+    if (!loops_were_allowed) {
+        if (setenv("_SSS_LOOPS", "NO" , 0) != 0) {
+            DEBUG(SSSDBG_OP_FAILURE, "Failed to restore _SSS_LOOPS.\n");
+        }
     }
     talloc_free(list);
     if (ret != EOK) {
@@ -392,7 +398,7 @@ static void responder_idle_handler(struct tevent_context *ev,
         goto end;
     }
 
-    if ((now - rctx->last_request_time) > rctx->idle_timeout) {
+    if ((now - rctx->last_request_time) >= rctx->idle_timeout) {
         /* This responder is idle. Terminate it */
         DEBUG(SSSDBG_TRACE_INTERNAL,
               "Terminating idle responder [%p]\n", rctx);
@@ -1689,14 +1695,14 @@ errno_t responder_setup_idle_timeout_config(struct resp_ctx *rctx)
     if (rctx->idle_timeout == 0) {
         DEBUG(SSSDBG_TRACE_INTERNAL,
               "Responder idle timeout won't be set up as the "
-              "responder_idle_timeout is set to 0");
+              "responder_idle_timeout is set to 0\n");
     } else {
         /* Ensure that the responder timeout is at least sixty seconds */
         if (rctx->idle_timeout < 60) {
             DEBUG(SSSDBG_TRACE_INTERNAL,
                   "responder_idle_timeout is set to a value lower than "
-                  "the minimum allowed (60s).\n"
-                  "The minimum allowed value will be used.");
+                  "the minimum allowed (60s). "
+                  "The minimum allowed value will be used.\n");
 
             rctx->idle_timeout = 60;
         }
