@@ -25,6 +25,7 @@
 #include <sys/mman.h>
 #include <fcntl.h>
 #include "util/mmap_cache.h"
+#include "sss_client/idmap/sss_nss_idmap.h"
 #include "responder/nss/nss_private.h"
 #include "responder/nss/nsssrv_mmap_cache.h"
 
@@ -380,6 +381,8 @@ static const char *mc_type_to_str(enum sss_mc_type type)
         return "GROUP";
     case SSS_MC_INITGROUPS:
         return "INITGROUPS";
+    case SSS_MC_SID:
+        return "SID";
     default:
         return "-UNKNOWN-";
     }
@@ -500,6 +503,9 @@ static errno_t sss_mc_get_strs_offset(struct sss_mc_ctx *mcc,
     case SSS_MC_INITGROUPS:
         *_offset = offsetof(struct sss_mc_initgr_data, gids);
         return EOK;
+    case SSS_MC_SID:
+        *_offset = offsetof(struct sss_mc_sid_data, sid);
+        return EOK;
     default:
         DEBUG(SSSDBG_FATAL_FAILURE, "Unknown memory cache type.\n");
         return EINVAL;
@@ -520,6 +526,9 @@ static errno_t sss_mc_get_strs_len(struct sss_mc_ctx *mcc,
     case SSS_MC_INITGROUPS:
         *_len = ((struct sss_mc_initgr_data *)&rec->data)->data_len;
         return EOK;
+    case SSS_MC_SID:
+        *_len = ((struct sss_mc_sid_data *)&rec->data)->sid_len;
+        return EOK;
     default:
         DEBUG(SSSDBG_FATAL_FAILURE, "Unknown memory cache type.\n");
         return EINVAL;
@@ -527,9 +536,9 @@ static errno_t sss_mc_get_strs_len(struct sss_mc_ctx *mcc,
 }
 
 static struct sss_mc_rec *sss_mc_find_record(struct sss_mc_ctx *mcc,
-                                             struct sized_string *key)
+                                             const struct sized_string *key)
 {
-    struct sss_mc_rec *rec;
+    struct sss_mc_rec *rec = NULL;
     uint32_t hash;
     uint32_t slot;
     rel_ptr_t name_ptr;
@@ -596,22 +605,18 @@ static struct sss_mc_rec *sss_mc_find_record(struct sss_mc_ctx *mcc,
         }
 
         if (strcmp(key->str, t_key) == 0) {
-            break;
+            return rec;
         }
 
         slot = sss_mc_next_slot_with_hash(rec, hash);
     }
 
-    if (slot == MC_INVALID_VAL) {
-        return NULL;
-    }
-
-    return rec;
+    return NULL;
 }
 
 static errno_t sss_mc_get_record(struct sss_mc_ctx **_mcc,
                                  size_t rec_len,
-                                 struct sized_string *key,
+                                 const struct sized_string *key,
                                  struct sss_mc_rec **_rec)
 {
     struct sss_mc_ctx *mcc = *_mcc;
@@ -697,7 +702,7 @@ static inline void sss_mmap_chain_in_rec(struct sss_mc_ctx *mcc,
  ***************************************************************************/
 
 static errno_t sss_mmap_cache_invalidate(struct sss_mc_ctx *mcc,
-                                         struct sized_string *key)
+                                         const struct sized_string *key)
 {
     struct sss_mc_rec *rec;
 
@@ -722,12 +727,12 @@ static errno_t sss_mmap_cache_invalidate(struct sss_mc_ctx *mcc,
  ***************************************************************************/
 
 errno_t sss_mmap_cache_pw_store(struct sss_mc_ctx **_mcc,
-                                struct sized_string *name,
-                                struct sized_string *pw,
+                                const struct sized_string *name,
+                                const struct sized_string *pw,
                                 uid_t uid, gid_t gid,
-                                struct sized_string *gecos,
-                                struct sized_string *homedir,
-                                struct sized_string *shell)
+                                const struct sized_string *gecos,
+                                const struct sized_string *homedir,
+                                const struct sized_string *shell)
 {
     struct sss_mc_ctx *mcc = *_mcc;
     struct sss_mc_rec *rec;
@@ -796,14 +801,14 @@ errno_t sss_mmap_cache_pw_store(struct sss_mc_ctx **_mcc,
 }
 
 errno_t sss_mmap_cache_pw_invalidate(struct sss_mc_ctx *mcc,
-                                     struct sized_string *name)
+                                     const struct sized_string *name)
 {
     return sss_mmap_cache_invalidate(mcc, name);
 }
 
 errno_t sss_mmap_cache_pw_invalidate_uid(struct sss_mc_ctx *mcc, uid_t uid)
 {
-    struct sss_mc_rec *rec;
+    struct sss_mc_rec *rec = NULL;
     struct sss_mc_pwd_data *data;
     uint32_t hash;
     uint32_t slot;
@@ -866,10 +871,10 @@ done:
  ***************************************************************************/
 
 int sss_mmap_cache_gr_store(struct sss_mc_ctx **_mcc,
-                            struct sized_string *name,
-                            struct sized_string *pw,
+                            const struct sized_string *name,
+                            const struct sized_string *pw,
                             gid_t gid, size_t memnum,
-                            char *membuf, size_t memsize)
+                            const char *membuf, size_t memsize)
 {
     struct sss_mc_ctx *mcc = *_mcc;
     struct sss_mc_rec *rec;
@@ -934,14 +939,14 @@ int sss_mmap_cache_gr_store(struct sss_mc_ctx **_mcc,
 }
 
 errno_t sss_mmap_cache_gr_invalidate(struct sss_mc_ctx *mcc,
-                                     struct sized_string *name)
+                                     const struct sized_string *name)
 {
     return sss_mmap_cache_invalidate(mcc, name);
 }
 
 errno_t sss_mmap_cache_gr_invalidate_gid(struct sss_mc_ctx *mcc, gid_t gid)
 {
-    struct sss_mc_rec *rec;
+    struct sss_mc_rec *rec = NULL;
     struct sss_mc_grp_data *data;
     uint32_t hash;
     uint32_t slot;
@@ -1000,10 +1005,10 @@ done:
 }
 
 errno_t sss_mmap_cache_initgr_store(struct sss_mc_ctx **_mcc,
-                                    struct sized_string *name,
-                                    struct sized_string *unique_name,
+                                    const struct sized_string *name,
+                                    const struct sized_string *unique_name,
                                     uint32_t num_groups,
-                                    uint8_t *gids_buf)
+                                    const uint8_t *gids_buf)
 {
     struct sss_mc_ctx *mcc = *_mcc;
     struct sss_mc_rec *rec;
@@ -1037,9 +1042,6 @@ errno_t sss_mmap_cache_initgr_store(struct sss_mc_ctx **_mcc,
 
     MC_RAISE_BARRIER(rec);
 
-    /* We cannot use two keys for searching in initgroups cache.
-     * Use the first key twice.
-     */
     sss_mmap_set_rec_header(mcc, rec, rec_len, mcc->valid_time_slot,
                             name->str, name->len,
                             unique_name->str, unique_name->len);
@@ -1067,11 +1069,63 @@ errno_t sss_mmap_cache_initgr_store(struct sss_mc_ctx **_mcc,
 }
 
 errno_t sss_mmap_cache_initgr_invalidate(struct sss_mc_ctx *mcc,
-                                         struct sized_string *name)
+                                         const struct sized_string *name)
 {
     return sss_mmap_cache_invalidate(mcc, name);
 }
 
+errno_t sss_mmap_cache_sid_store(struct sss_mc_ctx **_mcc,
+                                 const struct sized_string *sid,
+                                 uint32_t id,
+                                 uint32_t type,
+                                 bool explicit_lookup)
+{
+    struct sss_mc_ctx *mcc = *_mcc;
+    struct sss_mc_rec *rec;
+    struct sss_mc_sid_data *data;
+    char idkey[16];
+    size_t rec_len;
+    int ret;
+
+    if (mcc == NULL) {
+        return EINVAL;
+    }
+
+    ret = snprintf(idkey, sizeof(idkey), "%d-%ld",
+                   (type == SSS_ID_TYPE_GID) ? SSS_ID_TYPE_GID : SSS_ID_TYPE_UID,
+                   (long)id);
+    if (ret > (sizeof(idkey) - 1)) {
+        return EINVAL;
+    }
+
+    rec_len = sizeof(struct sss_mc_rec) +
+              sizeof(struct sss_mc_sid_data) +
+              sid->len;
+
+    ret = sss_mc_get_record(_mcc, rec_len, sid, &rec);
+    if (ret != EOK) {
+        return ret;
+    }
+
+    data = (struct sss_mc_sid_data *)rec->data;
+    MC_RAISE_BARRIER(rec);
+
+    sss_mmap_set_rec_header(mcc, rec, rec_len, mcc->valid_time_slot,
+                            sid->str, sid->len, idkey, strlen(idkey) + 1);
+
+    data->name = MC_PTR_DIFF(data->sid, data);
+    data->type = type;
+    data->id = id;
+    data->populated_by = (explicit_lookup ? 1 : 0);
+    data->sid_len = sid->len;
+    memcpy(data->sid, sid->str, sid->len);
+
+    MC_LOWER_BARRIER(rec);
+    sss_mmap_chain_in_rec(mcc, rec);
+
+    return EOK;
+}
+
 /***************************************************************************
  * initialization
  ***************************************************************************/
@@ -1271,7 +1325,7 @@ errno_t sss_mmap_cache_init(TALLOC_CTX *mem_ctx, const char *name,
                             enum sss_mc_type type, size_t n_elem,
                             time_t timeout, struct sss_mc_ctx **mcc)
 {
-    /* sss_mc_header alone occupies whole slot,
+    /* sss_mc_rec alone occupies whole slot,
      * so each entry takes 2 slots at the very least
      */
     static const int PAYLOAD_FACTOR = 2;
