@@ -164,8 +164,8 @@ int main(int argc, const char *argv[])
     char *opt_logger = NULL;
     struct main_context *main_ctx;
     int ret;
-    uid_t uid;
-    gid_t gid;
+    uid_t uid = 0;
+    gid_t gid = 0;
 
     struct poptOption long_options[] = {
         POPT_AUTOHELP
@@ -209,7 +209,7 @@ int main(int argc, const char *argv[])
     }
 
     ret = server_setup("ssh", true, 0, uid, gid,
-                       CONFDB_SSH_CONF_ENTRY, &main_ctx);
+                       CONFDB_SSH_CONF_ENTRY, &main_ctx, true);
     if (ret != EOK) {
         return 2;
     }
