@@ -141,8 +141,8 @@ int main(int argc, const char *argv[])
     struct main_context *main_ctx;
     int ret;
     int pipe_fd = -1;
-    uid_t uid;
-    gid_t gid;
+    uid_t uid = 0;
+    gid_t gid = 0;
 
     struct poptOption long_options[] = {
         POPT_AUTOHELP
@@ -171,12 +171,9 @@ int main(int argc, const char *argv[])
 
     poptFreeContext(pc);
 
-    DEBUG_INIT(debug_level);
-
     /* set up things like debug, signals, daemonization, etc. */
     debug_log_file = "sssd_sudo";
-
-    sss_set_logger(opt_logger);
+    DEBUG_INIT(debug_level, opt_logger);
 
     if (!is_socket_activated()) {
         /* Create pipe file descriptors here with right ownerschip */
@@ -199,8 +196,8 @@ int main(int argc, const char *argv[])
         }
     }
 
-    ret = server_setup("sudo", 0, uid, gid, CONFDB_SUDO_CONF_ENTRY,
-                       &main_ctx);
+    ret = server_setup("sudo", true, 0, uid, gid, CONFDB_SUDO_CONF_ENTRY,
+                       &main_ctx, true);
     if (ret != EOK) {
         return 2;
     }
