@@ -46,10 +46,6 @@
 #include "common_private.h"
 #include "util/util_errors.h"
 
-#if HAVE_PTHREAD
-#include <pthread.h>
-#endif
-
 /*
 * Note we set MSG_NOSIGNAL to avoid
 * having to fiddle with signal masks
@@ -65,13 +61,20 @@
 
 /* common functions */
 
+#ifdef HAVE_PTHREAD_EXT
+static pthread_key_t sss_sd_key;
+static pthread_once_t sss_sd_key_initialized = PTHREAD_ONCE_INIT;
+static __thread int sss_cli_sd = -1; /* the sss client socket descriptor */
+static __thread struct stat sss_cli_sb; /* the sss client stat buffer */
+#else
 static int sss_cli_sd = -1; /* the sss client socket descriptor */
 static struct stat sss_cli_sb; /* the sss client stat buffer */
+#endif
 
 #if HAVE_FUNCTION_ATTRIBUTE_DESTRUCTOR
 __attribute__((destructor))
 #endif
-static void sss_cli_close_socket(void)
+void sss_cli_close_socket(void)
 {
     if (sss_cli_sd != -1) {
         close(sss_cli_sd);
@@ -79,6 +82,18 @@ static void sss_cli_close_socket(void)
     }
 }
 
+#ifdef HAVE_PTHREAD_EXT
+static void sss_at_thread_exit(void *v)
+{
+    sss_cli_close_socket();
+}
+
+static void init_sd_key(void)
+{
+    pthread_key_create(&sss_sd_key, sss_at_thread_exit);
+}
+#endif
+
 /* Requests:
  *
  * byte 0-3: 32bit unsigned with length (the complete packet length: 0 to X)
@@ -556,6 +571,16 @@ static int sss_cli_open_socket(int *errnop, const char *socket_name, int timeout
         return -1;
     }
 
+#ifdef HAVE_PTHREAD_EXT
+    pthread_once(&sss_sd_key_initialized, init_sd_key); /* once for all threads */
+
+    /* It actually doesn't matter what value to set for a key.
+     * The only important thing: key must be non-NULL to ensure
+     * destructor is executed at thread exit.
+     */
+    pthread_setspecific(sss_sd_key, &sss_cli_sd);
+#endif
+
     /* set as non-blocking, close on exec, and make sure standard
      * descriptors are not used */
     sd = make_safe_fd(sd);
@@ -996,19 +1021,7 @@ out:
     return ret;
 }
 
-void sss_pam_close_fd(void)
-{
-    sss_pam_lock();
-
-    if (sss_cli_sd != -1) {
-        close(sss_cli_sd);
-        sss_cli_sd = -1;
-    }
-
-    sss_pam_unlock();
-}
-
-static enum sss_status
+enum sss_status
 sss_cli_make_request_with_checks(enum sss_cli_command cmd,
                                  struct sss_cli_req_data *rd,
                                  int timeout,
@@ -1144,24 +1157,51 @@ errno_t sss_strnlen(const char *str, size_t maxlen, size_t *len)
 }
 
 #if HAVE_PTHREAD
-typedef void (*sss_mutex_init)(void);
+
+#ifdef HAVE_PTHREAD_EXT
+static bool sss_lock_free = true;
+static pthread_once_t sss_lock_mode_initialized = PTHREAD_ONCE_INIT;
+
+static void init_lock_mode(void)
+{
+    const char *env = getenv("SSS_LOCKFREE");
+
+    if ((env != NULL) && (strcasecmp(env, "NO") == 0)) {
+        sss_lock_free = false;
+    }
+}
+
+bool sss_is_lockfree_mode(void)
+{
+    pthread_once(&sss_lock_mode_initialized, init_lock_mode);
+    return sss_lock_free;
+}
+#endif
 
 struct sss_mutex sss_nss_mtx = { .mtx  = PTHREAD_MUTEX_INITIALIZER };
-
 static struct sss_mutex sss_pam_mtx = { .mtx  = PTHREAD_MUTEX_INITIALIZER };
-
-static struct sss_mutex sss_nss_mc_mtx = { .mtx  = PTHREAD_MUTEX_INITIALIZER };
-
 static struct sss_mutex sss_pac_mtx = { .mtx  = PTHREAD_MUTEX_INITIALIZER };
 
 static void sss_mt_lock(struct sss_mutex *m)
 {
+#ifdef HAVE_PTHREAD_EXT
+    if (sss_is_lockfree_mode()) {
+        return;
+    }
+#endif
+
     pthread_mutex_lock(&m->mtx);
     pthread_setcancelstate(PTHREAD_CANCEL_DISABLE, &m->old_cancel_state);
 }
 
 static void sss_mt_unlock(struct sss_mutex *m)
 {
+#ifdef HAVE_PTHREAD_EXT
+    if (sss_is_lockfree_mode()) {
+        return;
+    }
+#endif
+
     pthread_setcancelstate(m->old_cancel_state, NULL);
     pthread_mutex_unlock(&m->mtx);
 }
@@ -1176,7 +1216,7 @@ void sss_nss_unlock(void)
     sss_mt_unlock(&sss_nss_mtx);
 }
 
-/* NSS mutex wrappers */
+/* PAM mutex wrappers */
 void sss_pam_lock(void)
 {
     sss_mt_lock(&sss_pam_mtx);
@@ -1186,16 +1226,6 @@ void sss_pam_unlock(void)
     sss_mt_unlock(&sss_pam_mtx);
 }
 
-/* NSS mutex wrappers */
-void sss_nss_mc_lock(void)
-{
-    sss_mt_lock(&sss_nss_mc_mtx);
-}
-void sss_nss_mc_unlock(void)
-{
-    sss_mt_unlock(&sss_nss_mc_mtx);
-}
-
 /* PAC mutex wrappers */
 void sss_pac_lock(void)
 {
