@@ -117,7 +117,7 @@ static void close_fd(pam_handle_t *pamh, void *ptr, int err)
 #endif /* PAM_DATA_REPLACE */
 
     D(("Closing the fd"));
-    sss_pam_close_fd();
+    sss_cli_close_socket();
 }
 
 struct cert_auth_info {
@@ -702,6 +702,20 @@ static int user_info_otp_chpass(pam_handle_t *pamh)
     return PAM_SUCCESS;
 }
 
+static int user_info_pin_locked(pam_handle_t *pamh)
+{
+    int ret;
+
+    ret = do_pam_conversation(pamh, PAM_TEXT_INFO, _("PIN locked"),
+                              NULL, NULL);
+    if (ret != PAM_SUCCESS) {
+        D(("do_pam_conversation failed."));
+        return PAM_SYSTEM_ERR;
+    }
+
+    return PAM_SUCCESS;
+}
+
 static int user_info_account_expired(pam_handle_t *pamh, size_t buflen,
                                      uint8_t *buf)
 {
@@ -849,6 +863,9 @@ static int eval_user_info_response(pam_handle_t *pamh, size_t buflen,
         case SSS_PAM_USER_INFO_CHPASS_ERROR:
             ret = user_info_chpass_error(pamh, buflen, buf);
             break;
+        case SSS_PAM_USER_INFO_PIN_LOCKED:
+            ret = user_info_pin_locked(pamh);
+            break;
         case SSS_PAM_USER_INFO_ACCOUNT_EXPIRED:
             ret = user_info_account_expired(pamh, buflen, buf);
             break;
@@ -1200,6 +1217,59 @@ static int eval_response(pam_handle_t *pamh, size_t buflen, uint8_t *buf,
                         pi->pc = NULL;
                     }
                 }
+                break;
+            case SSS_CHILD_KEEP_ALIVE:
+                memcpy(&pi->child_pid, &buf[p], len);
+                break;
+            case SSS_PAM_OAUTH2_INFO:
+                if (buf[p + (len - 1)] != '\0') {
+                    D(("oauth2 info does not end with \\0."));
+                    break;
+                }
+
+                free(pi->oauth2_url);
+                pi->oauth2_url = strdup((char *) &buf[p]);
+                if (pi->oauth2_url == NULL) {
+                    D(("strdup failed"));
+                    break;
+                }
+
+                offset = strlen(pi->oauth2_url) + 1;
+                if (offset >= len) {
+                    D(("OAuth2 message size mismatch"));
+                    free(pi->oauth2_url);
+                    pi->oauth2_url = NULL;
+                    break;
+                }
+
+                free(pi->oauth2_url_complete);
+                pi->oauth2_url_complete = strdup((char *) &buf[p + offset]);
+                if (pi->oauth2_url_complete == NULL) {
+                    D(("strdup failed"));
+                    break;
+                }
+
+                offset = offset + strlen(pi->oauth2_url_complete) + 1;
+                if (offset >= len) {
+                    D(("OAuth2 message size mismatch"));
+                    free(pi->oauth2_url_complete);
+                    pi->oauth2_url_complete = NULL;
+                    break;
+                }
+
+                /* This field is optional. */
+                if (pi->oauth2_url_complete[0] == '\0') {
+                    free(pi->oauth2_url_complete);
+                    pi->oauth2_url_complete = NULL;
+                }
+
+                free(pi->oauth2_pin);
+                pi->oauth2_pin = strdup((char *) &buf[p + offset]);
+                if (pi->oauth2_pin == NULL) {
+                    D(("strdup failed"));
+                    break;
+                }
+
                 break;
             default:
                 D(("Unknown response type [%d]", type));
@@ -1335,6 +1405,7 @@ static void print_pam_items(struct pam_items *pi)
     D(("Authtok: %s", CHECK_AND_RETURN_PI_STRING(pi->pam_authtok)));
     D(("Newauthtok: %s", CHECK_AND_RETURN_PI_STRING(pi->pam_newauthtok)));
     D(("Cli_PID: %d", pi->cli_pid));
+    D(("Child_PID: %d", pi->child_pid));
     D(("Requested domains: %s", pi->requested_domains));
     D(("Flags: %d", pi->flags));
 }
@@ -1660,6 +1731,41 @@ static int prompt_2fa_single(pam_handle_t *pamh, struct pam_items *pi,
     return PAM_SUCCESS;
 }
 
+static int prompt_oauth2(pam_handle_t *pamh, struct pam_items *pi)
+{
+    char *answer = NULL;
+    char *msg;
+    int ret;
+
+    if (pi->oauth2_url_complete != NULL) {
+        ret = asprintf(&msg, _("Authenticate at %1$s and press ENTER."),
+                       pi->oauth2_url_complete);
+    } else {
+        ret = asprintf(&msg, _("Authenticate with PIN %1$s at %2$s and press "
+                       "ENTER."), pi->oauth2_pin, pi->oauth2_url);
+    }
+    if (ret == -1) {
+        return PAM_SYSTEM_ERR;
+    }
+
+    ret = do_pam_conversation(pamh, PAM_PROMPT_ECHO_OFF, msg, NULL, &answer);
+    free(msg);
+    if (ret != PAM_SUCCESS) {
+        D(("do_pam_conversation failed."));
+        return ret;
+    }
+
+    /* We don't care about answer here. We just need to notify that the
+     * authentication has finished. */
+    free(answer);
+
+    pi->pam_authtok = strdup(pi->oauth2_pin);
+    pi->pam_authtok_type = SSS_AUTHTOK_TYPE_OAUTH2;
+    pi->pam_authtok_size=strlen(pi->oauth2_pin);
+
+    return PAM_SUCCESS;
+}
+
 #define SC_PROMPT_FMT "PIN for %s: "
 
 #ifndef discard_const
@@ -1720,6 +1826,7 @@ static int prompt_multi_cert_gdm(pam_handle_t *pamh, struct pam_items *pi)
         ret = asprintf(&cai->choice_list_id, "%zu", c);
         if (ret == -1) {
             cai->choice_list_id = NULL;
+            free(prompt);
             ret = ENOMEM;
             goto done;
         }
@@ -1849,43 +1956,42 @@ static int prompt_multi_cert(pam_handle_t *pamh, struct pam_items *pi)
     return ret;
 }
 
+#define SC_INSERT_PROMPT _("Please (re)insert (different) Smartcard")
+
 static int prompt_sc_pin(pam_handle_t *pamh, struct pam_items *pi)
 {
     int ret;
     char *answer = NULL;
-    char *prompt;
-    size_t size;
+    char *prompt = NULL;
     size_t needed_size;
     const struct pam_conv *conv;
     const struct pam_message *mesg[2] = { NULL, NULL };
     struct pam_message m[2] = { { 0 }, { 0 } };
     struct pam_response *resp = NULL;
     struct cert_auth_info *cai = pi->selected_cert;
-    struct cert_auth_info empty_cai = { NULL, NULL, discard_const("Smartcard"),
-                                        NULL, NULL, NULL, NULL, NULL, NULL,
-                                        NULL, NULL };
 
-    if (cai == NULL && SERVICE_IS_GDM_SMARTCARD(pi)) {
-        cai = &empty_cai;
+    if (cai == NULL && (SERVICE_IS_GDM_SMARTCARD(pi)
+                            || (pi->flags & PAM_CLI_FLAGS_REQUIRE_CERT_AUTH))) {
+        ret = asprintf(&prompt, SC_INSERT_PROMPT);
     } else if (cai == NULL || cai->token_name == NULL
                     || *cai->token_name == '\0') {
         return PAM_SYSTEM_ERR;
+    } else {
+        ret = asprintf(&prompt, SC_PROMPT_FMT, cai->token_name);
     }
 
-    size = sizeof(SC_PROMPT_FMT) + strlen(cai->token_name);
-    prompt = malloc(size);
-    if (prompt == NULL) {
-        D(("malloc failed."));
-        return PAM_BUF_ERR;
-    }
-
-    ret = snprintf(prompt, size, SC_PROMPT_FMT, cai->token_name);
-    if (ret < 0 || ret >= size) {
-        D(("snprintf failed."));
-        free(prompt);
+    if (ret == -1) {
+        D(("asprintf failed."));
         return PAM_SYSTEM_ERR;
     }
 
+    if (cai == NULL) {
+        ret = do_pam_conversation(pamh, PAM_TEXT_INFO, prompt, NULL, NULL);
+        if (ret != PAM_SUCCESS) {
+            D(("Conversation failure: %s, ignored", pam_strerror(pamh, ret)));
+        }
+    }
+
     if (pi->user_name_hint) {
         ret = pam_get_item(pamh, PAM_CONV, (const void **)&conv);
         if (ret != PAM_SUCCESS) {
@@ -1970,6 +2076,14 @@ static int prompt_sc_pin(pam_handle_t *pamh, struct pam_items *pi)
         }
     }
 
+    if (cai == NULL) {
+        /* it is expected that the user just replaces the Smartcard which
+         * would trigger gdm to restart the PAM module, so it is not
+         * expected that this part of the code is reached. */
+        ret = PAM_AUTHINFO_UNAVAIL;
+        goto done;
+    }
+
     if (answer == NULL || *answer == '\0') {
         D(("Missing PIN."));
         ret = PAM_CRED_INSUFFICIENT;
@@ -2139,7 +2253,7 @@ static void eval_argv(pam_handle_t *pamh, int argc, const char **argv,
 static int prompt_by_config(pam_handle_t *pamh, struct pam_items *pi)
 {
     size_t c;
-    int ret;
+    int ret = PAM_SUCCESS;
 
     if (pi->pc == NULL || *pi->pc == NULL) {
         return PAM_SYSTEM_ERR;
@@ -2197,7 +2311,10 @@ static int get_authtok_for_authentication(pam_handle_t *pamh,
         }
         pi->pam_authtok_size = strlen(pi->pam_authtok);
     } else {
-        if (pi->pc != NULL) {
+        if (pi->oauth2_url != NULL) {
+            /* Prompt config is not supported for OAuth2. */
+            ret = prompt_oauth2(pamh, pi);
+        } else if (pi->pc != NULL) {
             ret = prompt_by_config(pamh, pi);
         } else {
             if (flags & PAM_CLI_FLAGS_USE_2FA
@@ -2222,7 +2339,8 @@ static int get_authtok_for_authentication(pam_handle_t *pamh,
                     }
                 }
                 ret = prompt_sc_pin(pamh, pi);
-            } else if (SERVICE_IS_GDM_SMARTCARD(pi)) {
+            } else if (SERVICE_IS_GDM_SMARTCARD(pi)
+                    || (pi->flags & PAM_CLI_FLAGS_REQUIRE_CERT_AUTH)) {
                /* Use pin prompt as fallback for gdm-smartcard */
                 ret = prompt_sc_pin(pamh, pi);
             } else {
