@@ -492,7 +492,8 @@ static errno_t sss_cli_getenv(const char *variable_name, char **_value)
 {
     char *value = getenv(variable_name);
     if (value == NULL) {
-        return ENOENT;
+        *_value = NULL;
+        return EOK;
     }
 
     *_value = strdup(value);
@@ -580,7 +581,7 @@ int pam_sm_authenticate(pam_handle_t *pamh,
     }
 
 done:
-    sss_pam_close_fd();
+    sss_cli_close_socket();
     free(username);
     free(domain);
     free(target);
