@@ -127,7 +127,6 @@ enum sss_cli_command {
     SSS_NSS_SETNETGRENT    = 0x0061,
     SSS_NSS_GETNETGRENT    = 0x0062,
     SSS_NSS_ENDNETGRENT    = 0x0063,
-    /* SSS_NSS_INNETGR     = 0x0064, */
 
 /* networks */
 
@@ -284,6 +283,20 @@ SSS_NSS_GETSIDBYGID   = 0x0119, /**< Takes an unsigned 32bit integer (POSIX GID)
                                      and return the zero terminated string
                                      representation of the SID of the object
                                      with the given UID. */
+SSS_NSS_GETORIGBYUSERNAME = 0x011A, /**< Takes a zero terminated fully qualified
+                                     user name and returns a list of zero
+                                     terminated strings with key-value pairs
+                                     where the first string is the key and
+                                     second the value. Hence the list should
+                                     have an even number of strings, if not
+                                     the whole list is invalid. */
+SSS_NSS_GETORIGBYGROUPNAME = 0x011B, /**< Takes a zero terminated fully qualified
+                                     group name and returns a list of zero
+                                     terminated strings with key-value pairs
+                                     where the first string is the key and
+                                     second the value. Hence the list should
+                                     have an even number of strings, if not
+                                     the whole list is invalid. */
 
 /* subid */
     SSS_NSS_GET_SUBID_RANGES = 0x0130, /**< Requests both subuid and subgid ranges
@@ -351,6 +364,11 @@ enum sss_authtok_type {
     SSS_AUTHTOK_TYPE_2FA_SINGLE = 0x0006, /**< Authentication token has two
                                            * factors in a single string, it may
                                            * or may no contain a trailing \\0 */
+    SSS_AUTHTOK_TYPE_OAUTH2 =     0x0007, /**< Authentication token is a
+                                           * oauth2 token for presented
+                                           * challenge that is acquired from
+                                           * Kerberos. It may or may no
+                                           * contain a trailing \\0 */
 };
 
 /**
@@ -373,6 +391,7 @@ enum pam_item_type {
     SSS_PAM_ITEM_NEWAUTHTOK,
     SSS_PAM_ITEM_CLI_LOCALE,
     SSS_PAM_ITEM_CLI_PID,
+    SSS_PAM_ITEM_CHILD_PID,
     SSS_PAM_ITEM_REQUESTED_DOMAINS,
     SSS_PAM_ITEM_FLAGS,
 };
@@ -492,6 +511,17 @@ enum response_type {
     SSS_PAM_PROMPT_CONFIG, /**< Contains data which controls which credentials
                             * are expected and how the user is prompted for
                             * them. */
+    SSS_CHILD_KEEP_ALIVE, /**< Indicates that the child process is kept alived
+                            * and further communication must be done with the
+                            * same child. The message is the pid of the child
+                            * process. */
+    SSS_PAM_OAUTH2_INFO,  /**< A message which contains the oauth2
+                            *  parameters for the user.
+                            * @param Three zero terminated strings:
+                            *   - verification_uri
+                            *   - verification_uri_complete
+                            *   - user_code
+                            */
 };
 
 /**
@@ -574,6 +604,8 @@ enum user_info_type {
                                         * value of 0 indicates that no message
                                         * is following. @param String with the
                                         * specified length. */
+
+    SSS_PAM_USER_INFO_PIN_LOCKED, /**< Tell the user that the PIN is locked */
 };
 /**
  * @}
@@ -657,7 +689,8 @@ int sss_pam_make_request(enum sss_cli_command cmd,
                          struct sss_cli_req_data *rd,
                          uint8_t **repbuf, size_t *replen,
                          int *errnop);
-void sss_pam_close_fd(void);
+
+void sss_cli_close_socket(void);
 
 /* Checks access to the PAC responder and opens the socket, if available.
  * Required for processes like krb5_child that need to open the socket
