@@ -107,7 +107,7 @@ def stop_sssd():
     while True:
         try:
             os.kill(pid, signal.SIGCONT)
-        except:
+        except OSError:
             break
         time.sleep(1)
 
@@ -132,7 +132,7 @@ def create_sssd_fixture(request):
     def teardown():
         try:
             stop_sssd()
-        except:
+        except Exception:
             pass
         for path in os.listdir(config.DB_PATH):
             os.unlink(config.DB_PATH + "/" + path)
@@ -509,28 +509,32 @@ def check_group_list(exp_groups_list):
 
 
 def assert_user_overriden():
-    # There is an issue in nss_wrapper [0] and nss_wrapper always looks into
-    # the files first before using the NSS module. This lets this check fail
-    # because the user is found in the file and hence will be returned
-    # without overridden values.
-    # In order to work this around while there's no fix for nss_wrapper, let's
-    # use the fully-qualified name when looking up the USER1
-    #
-    # https://bugzilla.samba.org/show_bug.cgi?id=12883)
-    ent.assert_passwd_by_name(USER1["name"]+"@files", OV_USER1)
+    """
+    There is an issue in nss_wrapper [0] and nss_wrapper always looks into
+    the files first before using the NSS module. This lets this check fail
+    because the user is found in the file and hence will be returned
+    without overridden values.
+    In order to work this around while there's no fix for nss_wrapper, let's
+    use the fully-qualified name when looking up the USER1
+
+    https://bugzilla.samba.org/show_bug.cgi?id=12883)
+    """
+    ent.assert_passwd_by_name(USER1["name"] + "@files", OV_USER1)
     ent.assert_passwd_by_name(OV_USER1["name"], OV_USER1)
 
 
 def assert_group_overriden():
-    # There is an issue in nss_wrapper [0] and nss_wrapper always looks into
-    # the files first before using the NSS module. This lets this check fail
-    # because the user is found in the file and hence will be returned
-    # without overridden values.
-    # In order to work this around while there's no fix for nss_wrapper, let's
-    # use the fully-qualified name when looking up the GROUP1
-    #
-    # https://bugzilla.samba.org/show_bug.cgi?id=12883)
-    ent.assert_group_by_name(GROUP1["name"]+"@files", OV_GROUP1)
+    """
+    There is an issue in nss_wrapper [0] and nss_wrapper always looks into
+    the files first before using the NSS module. This lets this check fail
+    because the user is found in the file and hence will be returned
+    without overridden values.
+    In order to work this around while there's no fix for nss_wrapper, let's
+    use the fully-qualified name when looking up the GROUP1
+
+    https://bugzilla.samba.org/show_bug.cgi?id=12883)
+    """
+    ent.assert_group_by_name(GROUP1["name"] + "@files", OV_GROUP1)
     ent.assert_group_by_name(OV_GROUP1["name"], OV_GROUP1)
 
 
@@ -784,6 +788,7 @@ def test_gid_zero_does_not_resolve(files_domain_only):
     assert res == NssReturnCode.NOTFOUND
 
 
+@pytest.mark.flaky(max_runs=5)
 def test_add_remove_add_file_group(
         setup_pw_with_canary, setup_gr_with_canary, files_domain_only
 ):
@@ -853,8 +858,8 @@ def test_getgrnam_no_members(add_group_nomem_with_canary, files_domain_only):
 
 
 def groupadd_list(grp_ops, groups):
-    for grp in groups:
-        grp_ops.groupadd(**grp)
+    for group in groups:
+        grp_ops.groupadd(**group)
 
 
 def useradd_list(pwd_ops, users):
@@ -1049,8 +1054,6 @@ def test_getgrnam_add_remove_ghosts(setup_pw_with_canary,
     """
     Test that a user is linked with a group
     """
-    pwd_ops = setup_pw_with_canary
-
     check_group(GROUP_NOMEM)
 
     modgroup = dict(GROUP_NOMEM)
@@ -1079,7 +1082,7 @@ def realloc_users(pwd_ops, num):
         user = user_generator(i)
         pwd_ops.useradd(**user)
 
-    user = user_generator(num-1)
+    user = user_generator(num - 1)
     check_user(user)
 
 
@@ -1097,7 +1100,7 @@ def test_realloc_users(setup_pw_with_canary, files_domain_only):
     Test that returning exactly FILES_REALLOC_CHUNK users (see files_ops.c)
     works fine to test reallocation logic.
     """
-    realloc_users(setup_pw_with_canary, FILES_REALLOC_CHUNK*3)
+    realloc_users(setup_pw_with_canary, FILES_REALLOC_CHUNK * 3)
 
 
 def realloc_groups(grp_ops, num):
@@ -1105,26 +1108,28 @@ def realloc_groups(grp_ops, num):
         group = group_generator(i)
         grp_ops.groupadd(**group)
 
-    group = group_generator(num-1)
+    group = group_generator(num - 1)
     check_group(group)
 
 
+@pytest.mark.flaky(max_runs=5)
 def test_realloc_groups_exact(setup_gr_with_canary, files_domain_only):
     """
     Test that returning exactly FILES_REALLOC_CHUNK groups (see files_ops.c)
     works fine to test reallocation logic. Test exact number of groups to
     check for off-by-one errors.
     """
-    realloc_groups(setup_gr_with_canary, FILES_REALLOC_CHUNK*3)
+    realloc_groups(setup_gr_with_canary, FILES_REALLOC_CHUNK * 3)
 
 
+@pytest.mark.flaky(max_runs=5)
 def test_realloc_groups(setup_gr_with_canary, files_domain_only):
     """
     Test that returning exactly FILES_REALLOC_CHUNK groups (see files_ops.c)
     works fine to test reallocation logic. Test exact number of groups to
     check for off-by-one errors.
     """
-    realloc_groups(setup_gr_with_canary, FILES_REALLOC_CHUNK*3)
+    realloc_groups(setup_gr_with_canary, FILES_REALLOC_CHUNK * 3)
 
 
 # Files domain autoconfiguration tests
@@ -1205,8 +1210,8 @@ def test_multiple_files_created_after_startup(add_user_with_canary,
 
     # touch the files
     for fpath in (alt_passwd_path, alt_group_path):
-        with open(fpath, "w") as f:
-            pass
+        with open(fpath, "w"):
+            os.utime(fpath)
 
     alt_pwops = PasswdOps(alt_passwd_path)
     alt_grops = GroupOps(alt_group_path)
