@@ -26,7 +26,6 @@ import time
 import signal
 import sys
 from datetime import datetime
-from requests import HTTPError
 
 import kdc
 import krb5utils
@@ -36,11 +35,6 @@ from intg.files_ops import passwd_ops_setup
 
 MAX_SECRETS = 10
 
-USER1 = dict(name='user1', passwd='x', uid=1000, gid=1000,
-             gecos='User for tests',
-             dir='/home/user1',
-             shell='/bin/bash')
-
 
 class KcmTestEnv(object):
     def __init__(self, k5kdc, k5util):
@@ -70,7 +64,7 @@ def kdc_instance(request):
     try:
         kdc_instance.set_up()
         kdc_instance.start_kdc()
-    except:
+    except Exception:
         kdc_instance.teardown()
         raise
     request.addfinalizer(kdc_instance.teardown)
@@ -110,7 +104,7 @@ def create_sssd_kcm_fixture(sock_path, krb5_conf_path, request):
         for _ in range(1, 100):
             try:
                 sck.connect(abs_sock_path)
-            except:
+            except Exception:
                 time.sleep(0.1)
             else:
                 break
@@ -212,8 +206,18 @@ def setup_for_kcm_renewals_secdb(passwd_ops_setup, request, kdc_instance):
     kcm_path = os.path.join(config.RUNSTATEDIR, "kcm.socket")
     sssd_conf = create_sssd_conf_renewals(kcm_path, "secdb",
                                           "10d", "60s", "10s")
-    passwd_ops_setup.useradd(**USER1)
-    return common_setup_for_kcm_mem(request, kdc_instance, kcm_path, sssd_conf)
+
+    testenv = common_setup_for_kcm_mem(request, kdc_instance, kcm_path, sssd_conf)
+
+    user = dict(name='user1', passwd='x',
+                uid=testenv.my_uid(), gid=testenv.my_uid(),
+                gecos='User for tests',
+                dir='/home/user1',
+                shell='/bin/bash')
+
+    passwd_ops_setup.useradd(**user)
+
+    return testenv
 
 
 def kcm_init_list_destroy(testenv):
@@ -409,9 +413,8 @@ def exercise_kswitch(testenv):
     assert len(cc_coll) == 2
     assert set(cc_coll['alice@KCMTEST']) == set(['krbtgt/KCMTEST@KCMTEST',
                                                  'host/somehostname@KCMTEST'])
-    assert set(cc_coll['bob@KCMTEST']) == set([
-                                    'krbtgt/KCMTEST@KCMTEST',
-                                    'host/differenthostname@KCMTEST'])
+    assert set(cc_coll['bob@KCMTEST']) == set(['krbtgt/KCMTEST@KCMTEST',
+                                               'host/differenthostname@KCMTEST'])
 
 
 def test_kcm_mem_kswitch(setup_for_kcm_mem):
@@ -463,9 +466,8 @@ def exercise_subsidiaries(testenv):
     assert len(cc_coll) == 2
     assert set(cc_coll['alice@KCMTEST']) == set(['krbtgt/KCMTEST@KCMTEST',
                                                  'host/somehostname@KCMTEST'])
-    assert set(cc_coll['bob@KCMTEST']) == set([
-                                            'krbtgt/KCMTEST@KCMTEST',
-                                            'host/differenthostname@KCMTEST'])
+    assert set(cc_coll['bob@KCMTEST']) == set(['krbtgt/KCMTEST@KCMTEST',
+                                               'host/differenthostname@KCMTEST'])
 
 
 def test_kcm_mem_subsidiaries(setup_for_kcm_mem):
@@ -512,6 +514,8 @@ def test_kcm_renewals(setup_for_kcm_renewals_secdb):
     """
     Test that basic KCM renewal works
     """
+    if "LC_TIME" in os.environ:
+        del os.environ["LC_TIME"]
     testenv = setup_for_kcm_renewals_secdb
     testenv.k5kdc.add_principal("user1", "Secret123")
 
