@@ -27,7 +27,6 @@ import signal
 import errno
 import subprocess
 import time
-import shutil
 
 import config
 import intg.ds_openldap
@@ -51,7 +50,7 @@ def ad_inst(request):
 
     try:
         instance.setup()
-    except:
+    except Exception:
         instance.teardown()
         raise
     request.addfinalizer(instance.teardown)
@@ -303,10 +302,10 @@ def cleanup_sssd_process():
         while True:
             try:
                 os.kill(pid, signal.SIGCONT)
-            except OSError as ex:
+            except OSError:
                 break
             time.sleep(1)
-    except OSError as ex:
+    except OSError:
         pass
     for path in os.listdir(config.DB_PATH):
         os.unlink(config.DB_PATH + "/" + path)
@@ -398,7 +397,7 @@ def test_password_prompting_config_global(ldap_conn, pam_prompting_config,
 
     try:
         out, err = sssctl.communicate(input="111")
-    except:
+    except Exception:
         sssctl.kill()
         out, err = sssctl.communicate()
 
@@ -424,7 +423,7 @@ def test_password_prompting_config_srv(ldap_conn, pam_prompting_config,
 
     try:
         out, err = sssctl.communicate(input="111")
-    except:
+    except Exception:
         sssctl.kill()
         out, err = sssctl.communicate()
 
@@ -462,7 +461,7 @@ def test_sc_auth_wrong_pin(simple_pam_cert_auth, env_for_sssctl):
 
     try:
         out, err = sssctl.communicate(input="111")
-    except:
+    except Exception:
         sssctl.kill()
         out, err = sssctl.communicate()
 
@@ -472,7 +471,7 @@ def test_sc_auth_wrong_pin(simple_pam_cert_auth, env_for_sssctl):
     if sssctl.wait() != 0:
         raise Exception("sssctl failed")
 
-    assert err.find("pam_authenticate for user [user1]: " +
+    assert err.find("pam_authenticate for user [user1]: "
                     "Authentication failure") != -1
 
 
@@ -486,7 +485,7 @@ def test_sc_auth(simple_pam_cert_auth, env_for_sssctl):
 
     try:
         out, err = sssctl.communicate(input="123456")
-    except:
+    except Exception:
         sssctl.kill()
         out, err = sssctl.communicate()
 
@@ -510,7 +509,7 @@ def test_require_sc_auth(simple_pam_cert_auth, env_for_sssctl):
 
     try:
         out, err = sssctl.communicate(input="123456")
-    except:
+    except Exception:
         sssctl.kill()
         out, err = sssctl.communicate()
 
@@ -539,7 +538,7 @@ def test_require_sc_auth_no_cert(simple_pam_cert_auth_no_cert, env_for_sssctl):
 
     try:
         out, err = sssctl.communicate(input="123456")
-    except:
+    except Exception:
         sssctl.kill()
         out, err = sssctl.communicate()
 
@@ -554,7 +553,7 @@ def test_require_sc_auth_no_cert(simple_pam_cert_auth_no_cert, env_for_sssctl):
         (end_time - start_time) >= 20 and \
         (end_time - start_time) < 40
     assert out.find("Please insert smart card\nPlease insert smart card") != -1
-    assert err.find("pam_authenticate for user [user1]: Authentication " +
+    assert err.find("pam_authenticate for user [user1]: Authentication "
                     "service cannot retrieve authentication info") != -1
 
 
@@ -569,7 +568,7 @@ def test_try_sc_auth_no_map(simple_pam_cert_auth, env_for_sssctl):
 
     try:
         out, err = sssctl.communicate(input="123456")
-    except:
+    except Exception:
         sssctl.kill()
         out, err = sssctl.communicate()
 
@@ -579,7 +578,7 @@ def test_try_sc_auth_no_map(simple_pam_cert_auth, env_for_sssctl):
     if sssctl.wait() != 0:
         raise Exception("sssctl failed")
 
-    assert err.find("pam_authenticate for user [user2]: Authentication " +
+    assert err.find("pam_authenticate for user [user2]: Authentication "
                     "service cannot retrieve authentication info") != -1
 
 
@@ -594,7 +593,7 @@ def test_try_sc_auth(simple_pam_cert_auth, env_for_sssctl):
 
     try:
         out, err = sssctl.communicate(input="123456")
-    except:
+    except Exception:
         sssctl.kill()
         out, err = sssctl.communicate()
 
@@ -621,7 +620,7 @@ def test_try_sc_auth_root(simple_pam_cert_auth, env_for_sssctl):
 
     try:
         out, err = sssctl.communicate(input="123456")
-    except:
+    except Exception:
         sssctl.kill()
         out, err = sssctl.communicate()
 
@@ -631,7 +630,7 @@ def test_try_sc_auth_root(simple_pam_cert_auth, env_for_sssctl):
     if sssctl.wait() != 0:
         raise Exception("sssctl failed")
 
-    assert err.find("pam_authenticate for user [root]: Authentication " +
+    assert err.find("pam_authenticate for user [root]: Authentication "
                     "service cannot retrieve authentication info") != -1
 
 
@@ -649,7 +648,7 @@ def test_sc_auth_missing_name(simple_pam_cert_auth, env_for_sssctl):
 
     try:
         out, err = sssctl.communicate(input="123456")
-    except:
+    except Exception:
         sssctl.kill()
         out, err = sssctl.communicate()
 
@@ -676,7 +675,7 @@ def test_sc_auth_missing_name_whitespace(simple_pam_cert_auth, env_for_sssctl):
 
     try:
         out, err = sssctl.communicate(input="123456")
-    except:
+    except Exception:
         sssctl.kill()
         out, err = sssctl.communicate()
 
@@ -704,7 +703,7 @@ def test_sc_auth_name_format(simple_pam_cert_auth_name_format, env_for_sssctl):
 
     try:
         out, err = sssctl.communicate(input="123456")
-    except:
+    except Exception:
         sssctl.kill()
         out, err = sssctl.communicate()
 
@@ -714,7 +713,7 @@ def test_sc_auth_name_format(simple_pam_cert_auth_name_format, env_for_sssctl):
     if sssctl.wait() != 0:
         raise Exception("sssctl failed")
 
-    assert err.find(r"pam_authenticate for user [auth_only\user1]: " +
+    assert err.find(r"pam_authenticate for user [auth_only\user1]: "
                     "Success") != -1
 
 
@@ -725,7 +724,7 @@ def kdc_instance(request):
     try:
         kdc_instance.set_up()
         kdc_instance.start_kdc()
-    except:
+    except Exception:
         kdc_instance.teardown()
         raise
     request.addfinalizer(kdc_instance.teardown)
@@ -763,7 +762,7 @@ def test_krb5_auth(setup_krb5, env_for_sssctl):
 
     try:
         out, err = sssctl.communicate(input="Secret123User1")
-    except:
+    except Exception:
         sssctl.kill()
         out, err = sssctl.communicate()
 
@@ -784,7 +783,7 @@ def test_krb5_auth(setup_krb5, env_for_sssctl):
 
     try:
         out, err = sssctl.communicate(input="Secret123User1")
-    except:
+    except Exception:
         sssctl.kill()
         out, err = sssctl.communicate()
 
@@ -794,7 +793,7 @@ def test_krb5_auth(setup_krb5, env_for_sssctl):
     if sssctl.wait() != 0:
         raise Exception("sssctl failed")
 
-    assert err.find(r"pam_authenticate for user [user2]: " +
+    assert err.find(r"pam_authenticate for user [user2]: "
                     "Authentication failure") != -1
 
 
@@ -830,7 +829,7 @@ def test_krb5_auth_domains(setup_krb5_domains, env_for_sssctl):
 
     try:
         out, err = sssctl.communicate(input="Secret123User1")
-    except:
+    except Exception:
         sssctl.kill()
         out, err = sssctl.communicate()
 
