@@ -62,16 +62,17 @@ static errno_t parse_cmdline(struct sss_cmdline *cmdline,
                              struct sss_domain_info **_domain)
 {
     enum sss_tool_opt require;
-    const char *input_name;
+    const char *input_name = NULL;
     const char *orig_name;
     struct sss_domain_info *domain;
     errno_t ret;
 
+    *_input_name = NULL;
     require = options == NULL ? SSS_TOOL_OPT_OPTIONAL : SSS_TOOL_OPT_REQUIRED;
 
     ret = sss_tool_popt_ex(cmdline, options, require,
                            NULL, NULL, "NAME", _("Specify name."),
-                           &input_name, NULL);
+                           SSS_TOOL_OPT_REQUIRED, &input_name, NULL);
     if (ret != EXIT_SUCCESS) {
         DEBUG(SSSDBG_CRIT_FAILURE, "Unable to parse command arguments\n");
         return ret;
@@ -81,6 +82,7 @@ static errno_t parse_cmdline(struct sss_cmdline *cmdline,
                               &orig_name, &domain);
     if (ret != EOK) {
         ERROR("Unable to parse name %s.\n", input_name);
+        free(discard_const(input_name));
         return ret;
     }
 
@@ -170,7 +172,8 @@ static errno_t parse_cmdline_find(struct sss_cmdline *cmdline,
     };
 
     ret = sss_tool_popt_ex(cmdline, options, SSS_TOOL_OPT_OPTIONAL,
-                           NULL, NULL, NULL, NULL, NULL, NULL);
+                           NULL, NULL, NULL, NULL, SSS_TOOL_OPT_REQUIRED,
+                           NULL, NULL);
     if (ret != EOK) {
         DEBUG(SSSDBG_CRIT_FAILURE, "Unable to parse command arguments\n");
         return ret;
@@ -200,7 +203,7 @@ static errno_t parse_cmdline_import(struct sss_cmdline *cmdline,
 
     ret = sss_tool_popt_ex(cmdline, NULL, SSS_TOOL_OPT_OPTIONAL,
                            NULL, NULL, "FILE", "File to import the data from.",
-                           _file, NULL);
+                           SSS_TOOL_OPT_REQUIRED, _file, NULL);
     if (ret != EOK) {
         DEBUG(SSSDBG_CRIT_FAILURE, "Unable to parse command arguments\n");
         return ret;
@@ -216,7 +219,7 @@ static errno_t parse_cmdline_export(struct sss_cmdline *cmdline,
 
     ret = sss_tool_popt_ex(cmdline, NULL, SSS_TOOL_OPT_OPTIONAL,
                            NULL, NULL, "FILE", "File to export the data to.",
-                           _file, NULL);
+                           SSS_TOOL_OPT_REQUIRED, _file, NULL);
     if (ret != EOK) {
         DEBUG(SSSDBG_CRIT_FAILURE, "Unable to parse command arguments\n");
         return ret;
@@ -454,7 +457,7 @@ get_object_domain(enum sysdb_member_type type,
                   struct sss_domain_info *domains)
 {
     TALLOC_CTX *tmp_ctx;
-    struct sss_domain_info *dom;
+    struct sss_domain_info *dom = NULL;
     struct ldb_result *res;
     const char *strtype;
     char *sysname;
@@ -1119,7 +1122,7 @@ list_user_overrides(TALLOC_CTX *mem_ctx,
                     const char *filter)
 {
     TALLOC_CTX *tmp_ctx;
-    struct override_user *objs;
+    struct override_user *objs = NULL;
     struct ldb_message **msgs;
     size_t count;
     size_t i;
@@ -1210,7 +1213,7 @@ list_group_overrides(TALLOC_CTX *mem_ctx,
                      const char *filter)
 {
     TALLOC_CTX *tmp_ctx;
-    struct override_group *objs;
+    struct override_group *objs = NULL;
     struct ldb_message **msgs;
     size_t count;
     size_t i;
@@ -1416,20 +1419,25 @@ static int override_user_add(struct sss_cmdline *cmdline,
     ret = parse_cmdline_user_add(cmdline, tool_ctx, &user);
     if (ret != EOK) {
         DEBUG(SSSDBG_CRIT_FAILURE, "Unable to parse command line.\n");
-        return ret;
+        goto done;
     }
 
     ret = get_user_domain_msg(tool_ctx, &user);
     if (ret != EOK) {
-        return ret;
+        goto done;
     }
 
     ret = override_user(tool_ctx, &user);
     if (ret != EOK) {
-        return ret;
+        goto done;
     }
 
-    return EOK;
+    ret = EOK;
+
+done:
+    free(discard_const(user.input_name));
+
+    return ret;
 }
 
 static int override_user_del(struct sss_cmdline *cmdline,
@@ -1442,21 +1450,26 @@ static int override_user_del(struct sss_cmdline *cmdline,
     ret = parse_cmdline_user_del(cmdline, tool_ctx, &user);
     if (ret != EOK) {
         DEBUG(SSSDBG_CRIT_FAILURE, "Unable to parse command line.\n");
-        return ret;
+        goto done;
     }
 
     ret = get_user_domain_msg(tool_ctx, &user);
     if (ret != EOK) {
-        return ret;
+        goto done;
     }
 
     ret = override_object_del(user.domain, SYSDB_MEMBER_USER, user.sysdb_name);
     if (ret != EOK) {
         DEBUG(SSSDBG_CRIT_FAILURE, "Unable to delete override object.\n");
-        return ret;
+        goto done;
     }
 
-    return EOK;
+    ret = EOK;
+
+done:
+    free(discard_const(user.input_name));
+
+    return ret;
 }
 
 static int override_user_find(struct sss_cmdline *cmdline,
@@ -1555,6 +1568,8 @@ static int override_user_show(struct sss_cmdline *cmdline,
 
 done:
     talloc_free(tmp_ctx);
+    free(discard_const(input.input_name));
+
     return ret;
 }
 
@@ -1564,8 +1579,8 @@ static int override_user_import(struct sss_cmdline *cmdline,
 {
     TALLOC_CTX *tmp_ctx;
     struct sss_colondb *db;
-    const char *filename;
-    struct override_user obj;
+    const char *filename = NULL;
+    struct override_user obj = {0};
     int linenum = 1;
     errno_t ret;
 
@@ -1636,6 +1651,8 @@ static int override_user_import(struct sss_cmdline *cmdline,
 
 done:
     talloc_free(tmp_ctx);
+    free(discard_const(filename));
+
     return ret;
 }
 
@@ -1643,22 +1660,27 @@ static int override_user_export(struct sss_cmdline *cmdline,
                                 struct sss_tool_ctx *tool_ctx,
                                 void *pvt)
 {
-    const char *filename;
+    const char *filename = NULL;
     errno_t ret;
 
     ret = parse_cmdline_export(cmdline, &filename);
     if (ret != EOK) {
         DEBUG(SSSDBG_CRIT_FAILURE, "Unable to parse command line.\n");
-        return ret;
+        goto done;
     }
 
     ret = user_export(filename, tool_ctx->domains, true, NULL);
     if (ret != EOK) {
         DEBUG(SSSDBG_CRIT_FAILURE, "Unable to export users\n");
-        return ret;
+        goto done;
     }
 
-    return EOK;
+    ret = EOK;
+
+done:
+    free(discard_const(filename));
+
+    return ret;
 }
 
 static int override_group_add(struct sss_cmdline *cmdline,
@@ -1671,20 +1693,25 @@ static int override_group_add(struct sss_cmdline *cmdline,
     ret = parse_cmdline_group_add(cmdline, tool_ctx, &group);
     if (ret != EOK) {
         DEBUG(SSSDBG_CRIT_FAILURE, "Unable to parse command line.\n");
-        return ret;
+        goto done;
     }
 
     ret = get_group_domain_msg(tool_ctx, &group);
     if (ret != EOK) {
-        return ret;
+        goto done;
     }
 
     ret = override_group(tool_ctx, &group);
     if (ret != EOK) {
-        return ret;
+        goto done;
     }
 
-    return EOK;
+    ret = EOK;
+
+done:
+    free(discard_const(group.input_name));
+
+    return ret;
 }
 
 static int override_group_del(struct sss_cmdline *cmdline,
@@ -1697,22 +1724,27 @@ static int override_group_del(struct sss_cmdline *cmdline,
     ret = parse_cmdline_group_del(cmdline, tool_ctx, &group);
     if (ret != EOK) {
         DEBUG(SSSDBG_CRIT_FAILURE, "Unable to parse command line.\n");
-        return ret;
+        goto done;
     }
 
     ret = get_group_domain_msg(tool_ctx, &group);
     if (ret != EOK) {
-        return ret;
+        goto done;
     }
 
     ret = override_object_del(group.domain, SYSDB_MEMBER_GROUP,
                               group.sysdb_name);
     if (ret != EOK) {
         DEBUG(SSSDBG_CRIT_FAILURE, "Unable to delete override object.\n");
-        return ret;
+        goto done;
     }
 
-    return EOK;
+    ret = EOK;
+
+done:
+    free(discard_const(group.input_name));
+
+    return ret;
 }
 
 static int override_group_find(struct sss_cmdline *cmdline,
@@ -1811,6 +1843,8 @@ static int override_group_show(struct sss_cmdline *cmdline,
 
 done:
     talloc_free(tmp_ctx);
+    free(discard_const(input.input_name));
+
     return ret;
 }
 
@@ -1820,8 +1854,8 @@ static int override_group_import(struct sss_cmdline *cmdline,
 {
     TALLOC_CTX *tmp_ctx;
     struct sss_colondb *db;
-    const char *filename;
-    struct override_group obj;
+    const char *filename = NULL;
+    struct override_group obj = {0};
     int linenum = 1;
     errno_t ret;
 
@@ -1887,6 +1921,8 @@ static int override_group_import(struct sss_cmdline *cmdline,
 
 done:
     talloc_free(tmp_ctx);
+    free(discard_const(filename));
+
     return ret;
 }
 
@@ -1894,22 +1930,27 @@ static int override_group_export(struct sss_cmdline *cmdline,
                                  struct sss_tool_ctx *tool_ctx,
                                  void *pvt)
 {
-    const char *filename;
+    const char *filename = NULL;
     errno_t ret;
 
     ret = parse_cmdline_export(cmdline, &filename);
     if (ret != EOK) {
         DEBUG(SSSDBG_CRIT_FAILURE, "Unable to parse command line.\n");
-        return ret;
+        goto done;
     }
 
     ret = group_export(filename, tool_ctx->domains, true, NULL);
     if (ret != EOK) {
         DEBUG(SSSDBG_CRIT_FAILURE, "Unable to export groups\n");
-        return ret;
+        goto done;
     }
 
-    return EOK;
+    ret = EOK;
+
+done:
+    free(discard_const(filename));
+
+    return ret;
 }
 
 int main(int argc, const char **argv)
