@@ -27,14 +27,12 @@
 
 #include "db/sysdb.h"
 #include "confdb/confdb.h"
-#include "util/nss_dl_load.h"
 #include "util/strtonum.h"
 #include "util/util.h"
 #include "util/safe-format-string.h"
 #include "responder/common/responder.h"
 
 #define NAME_DOMAIN_PATTERN_OPTIONS (SSS_REGEXP_DUPNAMES | SSS_REGEXP_EXTENDED)
-#define NSS_BUFFER_SIZE 16384
 
 /* Function returns given realm name as new uppercase string */
 char *get_uppercase_realm(TALLOC_CTX *memctx, const char *name)
@@ -56,11 +54,6 @@ char *get_uppercase_realm(TALLOC_CTX *memctx, const char *name)
     return realm;
 }
 
-
-#define IPA_AD_DEFAULT_RE "(((?P<domain>[^\\\\]+)\\\\(?P<name>.+$))|" \
-                         "((?P<name>[^@]+)@(?P<domain>.+$))|" \
-                         "(^(?P<name>[^@\\\\]+)$))"
-
 static errno_t get_id_provider_default_re(TALLOC_CTX *mem_ctx,
                                           struct confdb_ctx *cdb,
                                           const char *conf_path,
@@ -73,8 +66,8 @@ static errno_t get_id_provider_default_re(TALLOC_CTX *mem_ctx,
     struct provider_default_re {
         const char *name;
         const char *re;
-    } provider_default_re[] = {{"ipa", IPA_AD_DEFAULT_RE},
-                               {"ad", IPA_AD_DEFAULT_RE},
+    } provider_default_re[] = {{"ipa", SSS_IPA_AD_DEFAULT_RE},
+                               {"ad", SSS_IPA_AD_DEFAULT_RE},
                                {NULL, NULL}};
 
     ret = confdb_get_string(cdb, mem_ctx, conf_path, CONFDB_DOMAIN_ID_PROVIDER,
@@ -224,8 +217,7 @@ int sss_names_init(TALLOC_CTX *mem_ctx, struct confdb_ctx *cdb,
     }
 
     if (!re_pattern) {
-        re_pattern = talloc_strdup(tmpctx,
-                                   "(?P<name>[^@]+)@?(?P<domain>[^@]*$)");
+        re_pattern = talloc_strdup(tmpctx, SSS_DEFAULT_RE);
         if (!re_pattern) {
             ret = ENOMEM;
             goto done;
@@ -263,7 +255,7 @@ done:
 int sss_ad_default_names_ctx(TALLOC_CTX *mem_ctx,
                              struct sss_names_ctx **_out)
 {
-    return sss_names_init_from_args(mem_ctx, IPA_AD_DEFAULT_RE,
+    return sss_names_init_from_args(mem_ctx, SSS_IPA_AD_DEFAULT_RE,
                                     CONFDB_DEFAULT_FULL_NAME_FORMAT,
                                     _out);
 }
@@ -329,7 +321,7 @@ static struct sss_domain_info * match_any_domain_or_subdomain_name(
         return dom;
     }
 
-    return find_domain_by_name(dom, dmatch, true);
+    return find_domain_by_name_ex(dom, dmatch, true, SSS_GND_SUBDOMAINS);
 }
 
 int sss_parse_name_for_domains(TALLOC_CTX *memctx,
@@ -574,23 +566,10 @@ sss_fqname(char *str, size_t size, struct sss_names_ctx *nctx,
 
 errno_t sss_user_by_name_or_uid(const char *input, uid_t *_uid, gid_t *_gid)
 {
-    static struct sss_nss_ops nss_ops;
     uid_t uid;
     errno_t ret;
     char *endptr;
-    struct passwd pwd = { 0 };
-    int errnop = 0;
-    enum nss_status status;
-    static char s_nss_buffer[NSS_BUFFER_SIZE];
-
-    if (!nss_ops.dl_handle) {
-        ret = sss_load_nss_pw_symbols(&nss_ops);
-        if (ret != EOK) {
-            DEBUG(SSSDBG_OP_FAILURE, "Unable to load NSS symbols [%d]: %s\n",
-                  ret, sss_strerror(ret));
-            return ret;
-        }
-    }
+    struct passwd *pwd;
 
     /* Try if it's an ID first */
     uid = strtouint32(input, &endptr, 10);
@@ -602,27 +581,26 @@ errno_t sss_user_by_name_or_uid(const char *input, uid_t *_uid, gid_t *_gid)
             return ret;
         }
 
-        status = nss_ops.getpwnam_r(input, &pwd, s_nss_buffer, NSS_BUFFER_SIZE, &errnop);
+        /* Nope, maybe a username? */
+        pwd = getpwnam(input);
     } else {
-        status = nss_ops.getpwuid_r(uid, &pwd, s_nss_buffer, NSS_BUFFER_SIZE, &errnop);
+        pwd = getpwuid(uid);
     }
 
-    if (status != NSS_STATUS_SUCCESS) {
+    if (pwd == NULL) {
         DEBUG(SSSDBG_OP_FAILURE,
               "[%s] is neither a valid UID nor a user name which could be "
-              "resolved by getpwnam() [%d][%s]. status returned [%d]\n",
-              input, errnop, strerror(errnop), status);
+              "resolved by getpwnam().\n", input);
         return EINVAL;
     }
 
     if (_uid) {
-        *_uid = pwd.pw_uid;
+        *_uid = pwd->pw_uid;
     }
 
     if (_gid) {
-        *_gid = pwd.pw_gid;
+        *_gid = pwd->pw_gid;
     }
-
     return EOK;
 }
 
@@ -732,7 +710,7 @@ char **sss_create_internal_fqname_list(TALLOC_CTX *mem_ctx,
         fqname_list[i] = sss_create_internal_fqname(fqname_list,
                                                     shortname_list[i],
                                                     dom_name);
-        if (fqname_list == NULL) {
+        if (fqname_list[i] == NULL) {
             talloc_free(fqname_list);
             return NULL;
         }
