@@ -85,6 +85,7 @@ enum sssd_errors {
     ERR_INPUT_PARSE,
     ERR_NOT_FOUND,
     ERR_DOMAIN_NOT_FOUND,
+    ERR_NO_DOMAIN_ENABLED,
     ERR_INVALID_FILTER,
     ERR_NO_POSIX,
     ERR_DUP_EXTRA_ATTR,
@@ -111,6 +112,7 @@ enum sssd_errors {
     ERR_TRUST_FOREST_UNKNOWN,
     ERR_P11_CHILD,
     ERR_P11_CHILD_TIMEOUT,
+    ERR_P11_PIN_LOCKED,
     ERR_ADDR_FAMILY_NOT_SUPPORTED,
     ERR_SBUS_SENDER_BUS,
     ERR_SUBDOM_INACTIVE,
@@ -146,6 +148,8 @@ enum sssd_errors {
     ERR_GID_DUPLICATED,
     ERR_MULTIPLE_ENTRIES,
     ERR_UNSUPPORTED_RANGE_TYPE,
+    ERR_PROXY_CHILD_SIGNAL,
+    ERR_CHECK_PAC_FAILED,
 
     /* DBUS Errors */
     ERR_SBUS_KILL_CONNECTION,
